Module: Aws::IoTTwinMaker::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-iottwinmaker/errors.rb,
sig/errors.rbs
Overview
When IoTTwinMaker returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::IoTTwinMaker::Errors::ServiceError < Errors::ServiceError
You can rescue all IoTTwinMaker errors using ServiceError:
begin
# do stuff
rescue Aws::IoTTwinMaker::Errors::ServiceError
# rescues all IoTTwinMaker API errors
end
Request Context
ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
Error Classes
- AccessDeniedException
- ConflictException
- ConnectorFailureException
- ConnectorTimeoutException
- InternalServerException
- QueryTimeoutException
- ResourceNotFoundException
- ServiceQuotaExceededException
- ThrottlingException
- TooManyTagsException
- ValidationException
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, ConflictException, ConnectorFailureException, ConnectorTimeoutException, InternalServerException, QueryTimeoutException, ResourceNotFoundException, ServiceError, ServiceQuotaExceededException, ThrottlingException, TooManyTagsException, ValidationException