Module: Aws::IoTTwinMaker::Types
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Defined Under Namespace
Classes: AccessDeniedException, BatchPutPropertyError, BatchPutPropertyErrorEntry, BatchPutPropertyValuesRequest, BatchPutPropertyValuesResponse, BundleInformation, ColumnDescription, ComponentPropertyGroupRequest, ComponentPropertyGroupResponse, ComponentRequest, ComponentResponse, ComponentTypeSummary, ComponentUpdateRequest, ConflictException, ConnectorFailureException, ConnectorTimeoutException, CreateComponentTypeRequest, CreateComponentTypeResponse, CreateEntityRequest, CreateEntityResponse, CreateSceneRequest, CreateSceneResponse, CreateSyncJobRequest, CreateSyncJobResponse, CreateWorkspaceRequest, CreateWorkspaceResponse, DataConnector, DataType, DataValue, DeleteComponentTypeRequest, DeleteComponentTypeResponse, DeleteEntityRequest, DeleteEntityResponse, DeleteSceneRequest, DeleteSceneResponse, DeleteSyncJobRequest, DeleteSyncJobResponse, DeleteWorkspaceRequest, DeleteWorkspaceResponse, EntityPropertyReference, EntitySummary, ErrorDetails, ExecuteQueryRequest, ExecuteQueryResponse, FunctionRequest, FunctionResponse, GetComponentTypeRequest, GetComponentTypeResponse, GetEntityRequest, GetEntityResponse, GetPricingPlanRequest, GetPricingPlanResponse, GetPropertyValueHistoryRequest, GetPropertyValueHistoryResponse, GetPropertyValueRequest, GetPropertyValueResponse, GetSceneRequest, GetSceneResponse, GetSyncJobRequest, GetSyncJobResponse, GetWorkspaceRequest, GetWorkspaceResponse, InternalServerException, InterpolationParameters, LambdaFunction, ListComponentTypesFilter, ListComponentTypesRequest, ListComponentTypesResponse, ListEntitiesFilter, ListEntitiesRequest, ListEntitiesResponse, ListScenesRequest, ListScenesResponse, ListSyncJobsRequest, ListSyncJobsResponse, ListSyncResourcesRequest, ListSyncResourcesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListWorkspacesRequest, ListWorkspacesResponse, OrderBy, ParentEntityUpdateRequest, PricingPlan, PropertyDefinitionRequest, PropertyDefinitionResponse, PropertyFilter, PropertyGroupRequest, PropertyGroupResponse, PropertyLatestValue, PropertyRequest, PropertyResponse, PropertyValue, PropertyValueEntry, PropertyValueHistory, QueryTimeoutException, Relationship, RelationshipValue, ResourceNotFoundException, Row, SceneError, SceneSummary, ServiceQuotaExceededException, Status, SyncJobStatus, SyncJobSummary, SyncResourceFilter, SyncResourceStatus, SyncResourceSummary, TabularConditions, TagResourceRequest, TagResourceResponse, ThrottlingException, TooManyTagsException, UntagResourceRequest, UntagResourceResponse, UpdateComponentTypeRequest, UpdateComponentTypeResponse, UpdateEntityRequest, UpdateEntityResponse, UpdatePricingPlanRequest, UpdatePricingPlanResponse, UpdateSceneRequest, UpdateSceneResponse, UpdateWorkspaceRequest, UpdateWorkspaceResponse, ValidationException, WorkspaceSummary
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type in the entities in the list.
-
#extends_from ⇒ String
The component type that the component types in the list extend.
-
#external_id ⇒ String
The external ID.
-
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component types in the list are abstract.
-
#namespace ⇒ String
The namespace to which the component types in the list belong.
-
#parent_entity_id ⇒ String
The parent of the entities in the list.
-
#resource_id ⇒ String
The sync resource filter resource ID.
-
#resource_type ⇒ String
The sync resource filter resource type.
-
#state ⇒ String
The sync resource filter’s state.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type in the entities in the list.
1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1801 class ListEntitiesFilter < Struct.new( :parent_entity_id, :component_type_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParentEntityId < ListEntitiesFilter; end class ComponentTypeId < ListEntitiesFilter; end class ExternalId < ListEntitiesFilter; end class Unknown < ListEntitiesFilter; end end |
#extends_from ⇒ String
The component type that the component types in the list extend.
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1715 class ListComponentTypesFilter < Struct.new( :extends_from, :namespace, :is_abstract, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExtendsFrom < ListComponentTypesFilter; end class Namespace < ListComponentTypesFilter; end class IsAbstract < ListComponentTypesFilter; end class Unknown < ListComponentTypesFilter; end end |
#external_id ⇒ String
The external ID.
1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1801 class ListEntitiesFilter < Struct.new( :parent_entity_id, :component_type_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParentEntityId < ListEntitiesFilter; end class ComponentTypeId < ListEntitiesFilter; end class ExternalId < ListEntitiesFilter; end class Unknown < ListEntitiesFilter; end end |
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component types in the list are abstract.
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1715 class ListComponentTypesFilter < Struct.new( :extends_from, :namespace, :is_abstract, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExtendsFrom < ListComponentTypesFilter; end class Namespace < ListComponentTypesFilter; end class IsAbstract < ListComponentTypesFilter; end class Unknown < ListComponentTypesFilter; end end |
#namespace ⇒ String
The namespace to which the component types in the list belong.
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1715 class ListComponentTypesFilter < Struct.new( :extends_from, :namespace, :is_abstract, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExtendsFrom < ListComponentTypesFilter; end class Namespace < ListComponentTypesFilter; end class IsAbstract < ListComponentTypesFilter; end class Unknown < ListComponentTypesFilter; end end |
#parent_entity_id ⇒ String
The parent of the entities in the list.
1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1801 class ListEntitiesFilter < Struct.new( :parent_entity_id, :component_type_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParentEntityId < ListEntitiesFilter; end class ComponentTypeId < ListEntitiesFilter; end class ExternalId < ListEntitiesFilter; end class Unknown < ListEntitiesFilter; end end |
#resource_id ⇒ String
The sync resource filter resource ID.
2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2697 class SyncResourceFilter < Struct.new( :state, :resource_type, :resource_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class State < SyncResourceFilter; end class ResourceType < SyncResourceFilter; end class ResourceId < SyncResourceFilter; end class ExternalId < SyncResourceFilter; end class Unknown < SyncResourceFilter; end end |
#resource_type ⇒ String
The sync resource filter resource type
2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2697 class SyncResourceFilter < Struct.new( :state, :resource_type, :resource_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class State < SyncResourceFilter; end class ResourceType < SyncResourceFilter; end class ResourceId < SyncResourceFilter; end class ExternalId < SyncResourceFilter; end class Unknown < SyncResourceFilter; end end |
#state ⇒ String
The sync resource filter’s state.
2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2697 class SyncResourceFilter < Struct.new( :state, :resource_type, :resource_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class State < SyncResourceFilter; end class ResourceType < SyncResourceFilter; end class ResourceId < SyncResourceFilter; end class ExternalId < SyncResourceFilter; end class Unknown < SyncResourceFilter; end end |