Class: Aws::IoTTwinMaker::Types::BatchPutPropertyValuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::BatchPutPropertyValuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass BatchPutPropertyValuesRequest data as a hash:
{
entries: [ # required
{
entity_property_reference: { # required
component_name: "Name",
entity_id: "EntityId",
external_id_property: {
"String" => "String",
},
property_name: "Name", # required
},
property_values: [
{
time: "Time",
timestamp: Time.now,
value: { # required
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
},
],
},
],
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entries ⇒ Array<Types::PropertyValueEntry>
An object that maps strings to the property value entries to set.
-
#workspace_id ⇒ String
The ID of the workspace that contains the properties to set.
Instance Attribute Details
#entries ⇒ Array<Types::PropertyValueEntry>
An object that maps strings to the property value entries to set. Each string in the mapping must be unique to this object.
117 118 119 120 121 122 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 117 class BatchPutPropertyValuesRequest < Struct.new( :entries, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the properties to set.
117 118 119 120 121 122 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 117 class BatchPutPropertyValuesRequest < Struct.new( :entries, :workspace_id) SENSITIVE = [] include Aws::Structure end |