Class: Aws::IoTTwinMaker::Types::ComponentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::ComponentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that sets information about a component type create or update request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type.
-
#description ⇒ String
The description of the component request.
-
#properties ⇒ Hash<String,Types::PropertyRequest>
An object that maps strings to the properties to set in the component type.
-
#property_groups ⇒ Hash<String,Types::ComponentPropertyGroupRequest>
The property groups.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type.
187 188 189 190 191 192 193 194 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 187 class ComponentRequest < Struct.new( :description, :component_type_id, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component request.
187 188 189 190 191 192 193 194 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 187 class ComponentRequest < Struct.new( :description, :component_type_id, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,Types::PropertyRequest>
An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.
187 188 189 190 191 192 193 194 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 187 class ComponentRequest < Struct.new( :description, :component_type_id, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#property_groups ⇒ Hash<String,Types::ComponentPropertyGroupRequest>
The property groups.
187 188 189 190 191 192 193 194 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 187 class ComponentRequest < Struct.new( :description, :component_type_id, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |