Class: Aws::IoTTwinMaker::Types::ComponentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

An object that returns information about a component type create or update request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_nameString

The name of the component.

Returns:

  • (String)


232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#component_type_idString

The ID of the component type.

Returns:

  • (String)


232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#defined_inString

The name of the property definition set in the request.

Returns:

  • (String)


232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the component type.

Returns:

  • (String)


232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,Types::PropertyResponse>

An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.

Returns:



232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#property_groupsHash<String,Types::ComponentPropertyGroupResponse>

The property groups.

Returns:



232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::Status

The status of the component type.

Returns:



232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#sync_sourceString

The syncSource of the sync job, if this entity was created by a sync job.

Returns:

  • (String)


232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232

class ComponentResponse < Struct.new(
  :component_name,
  :description,
  :component_type_id,
  :status,
  :defined_in,
  :properties,
  :property_groups,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end