Class: Aws::IoTTwinMaker::Types::ComponentTypeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::ComponentTypeSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that contains information about a component type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the component type.
-
#component_type_id ⇒ String
The ID of the component type.
-
#creation_date_time ⇒ Time
The date and time when the component type was created.
-
#description ⇒ String
The description of the component type.
-
#status ⇒ Types::Status
The current status of the component type.
-
#update_date_time ⇒ Time
The date and time when the component type was last updated.
Instance Attribute Details
#arn ⇒ String
The ARN of the component type.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 323 class ComponentTypeSummary < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :status, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 323 class ComponentTypeSummary < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :status, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the component type was created.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 323 class ComponentTypeSummary < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :status, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 323 class ComponentTypeSummary < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :status, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The current status of the component type.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 323 class ComponentTypeSummary < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :status, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the component type was last updated.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 323 class ComponentTypeSummary < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :status, :update_date_time) SENSITIVE = [] include Aws::Structure end |