Class: Aws::IoTTwinMaker::Types::ComponentUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::ComponentUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass ComponentUpdateRequest data as a hash:
{
update_type: "CREATE", # accepts CREATE, UPDATE, DELETE
description: "Description",
component_type_id: "ComponentTypeId",
property_updates: {
"Name" => {
definition: {
data_type: {
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
nested_type: {
# recursive DataType
},
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: {
# recursive DataValueList
},
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
],
unit_of_measure: "String",
relationship: {
target_component_type_id: "ComponentTypeId",
relationship_type: "String",
},
},
is_required_in_entity: false,
is_external_id: false,
is_stored_externally: false,
is_time_series: false,
default_value: {
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: [
{
# recursive DataValue
},
],
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
configuration: {
"Name" => "Value",
},
},
value: {
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: [
{
# recursive DataValue
},
],
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
},
},
property_group_updates: {
"Name" => {
group_type: "TABULAR", # accepts TABULAR
property_names: ["Name"],
update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
},
},
}
The component update request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type.
-
#description ⇒ String
The description of the component type.
-
#property_group_updates ⇒ Hash<String,Types::ComponentPropertyGroupRequest>
The property group updates.
-
#property_updates ⇒ Hash<String,Types::PropertyRequest>
An object that maps strings to the properties to set in the component type update.
-
#update_type ⇒ String
The update type of the component update request.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type.
569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 569 class ComponentUpdateRequest < Struct.new( :update_type, :description, :component_type_id, :property_updates, :property_group_updates) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 569 class ComponentUpdateRequest < Struct.new( :update_type, :description, :component_type_id, :property_updates, :property_group_updates) SENSITIVE = [] include Aws::Structure end |
#property_group_updates ⇒ Hash<String,Types::ComponentPropertyGroupRequest>
The property group updates.
569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 569 class ComponentUpdateRequest < Struct.new( :update_type, :description, :component_type_id, :property_updates, :property_group_updates) SENSITIVE = [] include Aws::Structure end |
#property_updates ⇒ Hash<String,Types::PropertyRequest>
An object that maps strings to the properties to set in the component type update. Each string in the mapping must be unique to this object.
569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 569 class ComponentUpdateRequest < Struct.new( :update_type, :description, :component_type_id, :property_updates, :property_group_updates) SENSITIVE = [] include Aws::Structure end |
#update_type ⇒ String
The update type of the component update request.
569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 569 class ComponentUpdateRequest < Struct.new( :update_type, :description, :component_type_id, :property_updates, :property_group_updates) SENSITIVE = [] include Aws::Structure end |