Class: Aws::IoTTwinMaker::Types::CreateComponentTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::CreateComponentTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type.
-
#component_type_name ⇒ String
A friendly name for the component type.
-
#description ⇒ String
The description of the component type.
-
#extends_from ⇒ Array<String>
Specifies the parent component type to extend.
-
#functions ⇒ Hash<String,Types::FunctionRequest>
An object that maps strings to the functions in the component type.
-
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
-
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionRequest>
An object that maps strings to the property definitions in the component type.
- #property_groups ⇒ Hash<String,Types::PropertyGroupRequest>
-
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the component type.
-
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#component_type_name ⇒ String
A friendly name for the component type.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#extends_from ⇒ Array<String>
Specifies the parent component type to extend.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#functions ⇒ Hash<String,Types::FunctionRequest>
An object that maps strings to the functions in the component type. Each string in the mapping must be unique to this object.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionRequest>
An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#property_groups ⇒ Hash<String,Types::PropertyGroupRequest>
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the component type.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 399 class CreateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :tags, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |