Class: Aws::IoTTwinMaker::Types::CreateEntityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#componentsHash<String,Types::ComponentRequest>

An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#composite_componentsHash<String,Types::CompositeComponentRequest>

This is an object that maps strings to compositeComponent updates in the request. Each key of the map represents the componentPath of the compositeComponent.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entity.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

The name of the entity.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#parent_entity_idString

The ID of the entity's parent entity.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Metadata that you can use to manage the entity.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace that contains the entity.



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :composite_components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end