Class: Aws::IoTTwinMaker::Types::CreateSceneRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass CreateSceneRequest data as a hash:

{
  capabilities: ["SceneCapability"],
  content_location: "S3Url", # required
  description: "Description",
  scene_id: "Id", # required
  tags: {
    "TagKey" => "TagValue",
  },
  workspace_id: "Id", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capabilitiesArray<String>

A list of capabilities that the scene uses to render itself.

Returns:

  • (Array<String>)


874
875
876
877
878
879
880
881
882
883
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874

class CreateSceneRequest < Struct.new(
  :capabilities,
  :content_location,
  :description,
  :scene_id,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#content_locationString

The relative path that specifies the location of the content definition file.

Returns:

  • (String)


874
875
876
877
878
879
880
881
882
883
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874

class CreateSceneRequest < Struct.new(
  :capabilities,
  :content_location,
  :description,
  :scene_id,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description for this scene.

Returns:

  • (String)


874
875
876
877
878
879
880
881
882
883
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874

class CreateSceneRequest < Struct.new(
  :capabilities,
  :content_location,
  :description,
  :scene_id,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#scene_idString

The ID of the scene.

Returns:

  • (String)


874
875
876
877
878
879
880
881
882
883
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874

class CreateSceneRequest < Struct.new(
  :capabilities,
  :content_location,
  :description,
  :scene_id,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Metadata that you can use to manage the scene.

Returns:

  • (Hash<String,String>)


874
875
876
877
878
879
880
881
882
883
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874

class CreateSceneRequest < Struct.new(
  :capabilities,
  :content_location,
  :description,
  :scene_id,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace that contains the scene.

Returns:

  • (String)


874
875
876
877
878
879
880
881
882
883
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874

class CreateSceneRequest < Struct.new(
  :capabilities,
  :content_location,
  :description,
  :scene_id,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end