Class: Aws::IoTTwinMaker::Types::CreateSyncJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::CreateSyncJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#sync_role ⇒ String
The SyncJob IAM role.
-
#sync_source ⇒ String
The sync source.
-
#tags ⇒ Hash<String,String>
The SyncJob tags.
-
#workspace_id ⇒ String
The workspace Id.
Instance Attribute Details
#sync_role ⇒ String
The SyncJob IAM role. This IAM role is used by the sync job to read from the syncSource, and create, update or delete the corresponding resources.
571 572 573 574 575 576 577 578 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571 class CreateSyncJobRequest < Struct.new( :workspace_id, :sync_source, :sync_role, :tags) SENSITIVE = [] include Aws::Structure end |
#sync_source ⇒ String
The sync source.
<note markdown=“1”> Currently the only supported syncSoucre is `SITEWISE `.
</note>
571 572 573 574 575 576 577 578 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571 class CreateSyncJobRequest < Struct.new( :workspace_id, :sync_source, :sync_role, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The SyncJob tags.
571 572 573 574 575 576 577 578 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571 class CreateSyncJobRequest < Struct.new( :workspace_id, :sync_source, :sync_role, :tags) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The workspace Id.
571 572 573 574 575 576 577 578 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571 class CreateSyncJobRequest < Struct.new( :workspace_id, :sync_source, :sync_role, :tags) SENSITIVE = [] include Aws::Structure end |