Class: Aws::IoTTwinMaker::Types::CreateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::CreateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass CreateWorkspaceRequest data as a hash:
{
description: "Description",
role: "RoleArn", # required
s3_location: "S3Location", # required
tags: {
"TagKey" => "TagValue",
},
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the workspace.
-
#role ⇒ String
The ARN of the execution role associated with the workspace.
-
#s3_location ⇒ String
The ARN of the S3 bucket where resources associated with the workspace are stored.
-
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the workspace.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#description ⇒ String
The description of the workspace.
934 935 936 937 938 939 940 941 942 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934 class CreateWorkspaceRequest < Struct.new( :description, :role, :s3_location, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The ARN of the execution role associated with the workspace.
934 935 936 937 938 939 940 941 942 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934 class CreateWorkspaceRequest < Struct.new( :description, :role, :s3_location, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#s3_location ⇒ String
The ARN of the S3 bucket where resources associated with the workspace are stored.
934 935 936 937 938 939 940 941 942 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934 class CreateWorkspaceRequest < Struct.new( :description, :role, :s3_location, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the workspace
934 935 936 937 938 939 940 941 942 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934 class CreateWorkspaceRequest < Struct.new( :description, :role, :s3_location, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
934 935 936 937 938 939 940 941 942 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934 class CreateWorkspaceRequest < Struct.new( :description, :role, :s3_location, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |