Class: Aws::IoTTwinMaker::Types::CreateWorkspaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::CreateWorkspaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the workspace.
-
#creation_date_time ⇒ Time
The date and time when the workspace was created.
Instance Attribute Details
#arn ⇒ String
The ARN of the workspace.
952 953 954 955 956 957 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 952 class CreateWorkspaceResponse < Struct.new( :arn, :creation_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the workspace was created.
952 953 954 955 956 957 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 952 class CreateWorkspaceResponse < Struct.new( :arn, :creation_date_time) SENSITIVE = [] include Aws::Structure end |