Class: Aws::IoTTwinMaker::Types::DataConnector
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::DataConnector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass DataConnector data as a hash:
{
is_native: false,
lambda: {
arn: "LambdaArn", # required
},
}
The data connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_native ⇒ Boolean
A Boolean value that specifies whether the data connector is native to IoT TwinMaker.
-
#lambda ⇒ Types::LambdaFunction
The Lambda function associated with this data connector.
Instance Attribute Details
#is_native ⇒ Boolean
A Boolean value that specifies whether the data connector is native to IoT TwinMaker.
980 981 982 983 984 985 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 980 class DataConnector < Struct.new( :is_native, :lambda) SENSITIVE = [] include Aws::Structure end |
#lambda ⇒ Types::LambdaFunction
The Lambda function associated with this data connector.
980 981 982 983 984 985 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 980 class DataConnector < Struct.new( :is_native, :lambda) SENSITIVE = [] include Aws::Structure end |