Class: Aws::IoTTwinMaker::Types::DataType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass DataType data as a hash:

{
  type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
  nested_type: {
    type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
    nested_type: {
      # recursive DataType
    },
    allowed_values: [
      {
        boolean_value: false,
        double_value: 1.0,
        integer_value: 1,
        long_value: 1,
        string_value: "String",
        list_value: {
          # recursive DataValueList
        },
        map_value: {
          "String" => {
            # recursive DataValue
          },
        },
        relationship_value: {
          target_entity_id: "EntityId",
          target_component_name: "Name",
        },
        expression: "Expression",
      },
    ],
    unit_of_measure: "String",
    relationship: {
      target_component_type_id: "ComponentTypeId",
      relationship_type: "String",
    },
  },
  allowed_values: [
    {
      boolean_value: false,
      double_value: 1.0,
      integer_value: 1,
      long_value: 1,
      string_value: "String",
      list_value: {
        # recursive DataValueList
      },
      map_value: {
        "String" => {
          # recursive DataValue
        },
      },
      relationship_value: {
        target_entity_id: "EntityId",
        target_component_name: "Name",
      },
      expression: "Expression",
    },
  ],
  unit_of_measure: "String",
  relationship: {
    target_component_type_id: "ComponentTypeId",
    relationship_type: "String",
  },
}

An object that specifies the data type of a property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_valuesArray<Types::DataValue>

The allowed values for this data type.

Returns:



1208
1209
1210
1211
1212
1213
1214
1215
1216
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1208

class DataType < Struct.new(
  :type,
  :nested_type,
  :allowed_values,
  :unit_of_measure,
  :relationship)
  SENSITIVE = []
  include Aws::Structure
end

#nested_typeTypes::DataType

The nested type in the data type.

Returns:



1208
1209
1210
1211
1212
1213
1214
1215
1216
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1208

class DataType < Struct.new(
  :type,
  :nested_type,
  :allowed_values,
  :unit_of_measure,
  :relationship)
  SENSITIVE = []
  include Aws::Structure
end

#relationshipTypes::Relationship

A relationship that associates a component with another component.

Returns:



1208
1209
1210
1211
1212
1213
1214
1215
1216
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1208

class DataType < Struct.new(
  :type,
  :nested_type,
  :allowed_values,
  :unit_of_measure,
  :relationship)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The underlying type of the data type.

Returns:

  • (String)


1208
1209
1210
1211
1212
1213
1214
1215
1216
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1208

class DataType < Struct.new(
  :type,
  :nested_type,
  :allowed_values,
  :unit_of_measure,
  :relationship)
  SENSITIVE = []
  include Aws::Structure
end

#unit_of_measureString

The unit of measure used in this data type.

Returns:

  • (String)


1208
1209
1210
1211
1212
1213
1214
1215
1216
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1208

class DataType < Struct.new(
  :type,
  :nested_type,
  :allowed_values,
  :unit_of_measure,
  :relationship)
  SENSITIVE = []
  include Aws::Structure
end