Class: Aws::IoTTwinMaker::Types::DataValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass DataValue data as a hash:

{
  boolean_value: false,
  double_value: 1.0,
  integer_value: 1,
  long_value: 1,
  string_value: "String",
  list_value: [
    {
      boolean_value: false,
      double_value: 1.0,
      integer_value: 1,
      long_value: 1,
      string_value: "String",
      list_value: {
        # recursive DataValueList
      },
      map_value: {
        "String" => {
          # recursive DataValue
        },
      },
      relationship_value: {
        target_entity_id: "EntityId",
        target_component_name: "Name",
      },
      expression: "Expression",
    },
  ],
  map_value: {
    "String" => {
      boolean_value: false,
      double_value: 1.0,
      integer_value: 1,
      long_value: 1,
      string_value: "String",
      list_value: [
        {
          # recursive DataValue
        },
      ],
      map_value: {
        # recursive DataValueMap
      },
      relationship_value: {
        target_entity_id: "EntityId",
        target_component_name: "Name",
      },
      expression: "Expression",
    },
  },
  relationship_value: {
    target_entity_id: "EntityId",
    target_component_name: "Name",
  },
  expression: "Expression",
}

An object that specifies a value for a property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#boolean_valueBoolean

A Boolean value.

Returns:

  • (Boolean)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#double_valueFloat

A double value.

Returns:

  • (Float)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#expressionString

An expression that produces the value.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#integer_valueInteger

An integer value.

Returns:

  • (Integer)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#list_valueArray<Types::DataValue>

A list of multiple values.

Returns:



1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#long_valueInteger

A long value.

Returns:

  • (Integer)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#map_valueHash<String,Types::DataValue>

An object that maps strings to multiple `DataValue` objects.

Returns:



1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#relationship_valueTypes::RelationshipValue

A value that relates a component to another component.



1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end

#string_valueString

A string value.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1316

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :integer_value,
  :long_value,
  :string_value,
  :list_value,
  :map_value,
  :relationship_value,
  :expression)
  SENSITIVE = []
  include Aws::Structure
end