Class: Aws::IoTTwinMaker::Types::DeleteComponentTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::DeleteComponentTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass DeleteComponentTypeRequest data as a hash:
{
component_type_id: "ComponentTypeId", # required
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type to delete.
-
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type to delete.
1213 1214 1215 1216 1217 1218 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1213 class DeleteComponentTypeRequest < Struct.new( :component_type_id, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
1213 1214 1215 1216 1217 1218 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1213 class DeleteComponentTypeRequest < Struct.new( :component_type_id, :workspace_id) SENSITIVE = [] include Aws::Structure end |