Class: Aws::IoTTwinMaker::Types::DeleteComponentTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::DeleteComponentTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The current state of the component type to be deleted.
Instance Attribute Details
#state ⇒ String
The current state of the component type to be deleted.
767 768 769 770 771 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 767 class DeleteComponentTypeResponse < Struct.new( :state) SENSITIVE = [] include Aws::Structure end |