Class: Aws::IoTTwinMaker::Types::DeleteEntityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::DeleteEntityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass DeleteEntityRequest data as a hash:
{
workspace_id: "Id", # required
entity_id: "EntityId", # required
is_recursive: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity_id ⇒ String
The ID of the entity to delete.
-
#is_recursive ⇒ Boolean
A Boolean value that specifies whether the operation deletes child entities.
-
#workspace_id ⇒ String
The ID of the workspace that contains the entity to delete.
Instance Attribute Details
#entity_id ⇒ String
The ID of the entity to delete.
1385 1386 1387 1388 1389 1390 1391 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1385 class DeleteEntityRequest < Struct.new( :workspace_id, :entity_id, :is_recursive) SENSITIVE = [] include Aws::Structure end |
#is_recursive ⇒ Boolean
A Boolean value that specifies whether the operation deletes child entities.
1385 1386 1387 1388 1389 1390 1391 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1385 class DeleteEntityRequest < Struct.new( :workspace_id, :entity_id, :is_recursive) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the entity to delete.
1385 1386 1387 1388 1389 1390 1391 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1385 class DeleteEntityRequest < Struct.new( :workspace_id, :entity_id, :is_recursive) SENSITIVE = [] include Aws::Structure end |