Class: Aws::IoTTwinMaker::Types::EntitySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::EntitySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that contains information about an entity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the entity.
-
#creation_date_time ⇒ Time
The date and time when the entity was created.
-
#description ⇒ String
The description of the entity.
-
#entity_id ⇒ String
The ID of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#has_child_entities ⇒ Boolean
A Boolean value that specifies whether the entity has child entities or not.
-
#parent_entity_id ⇒ String
The ID of the parent entity.
-
#status ⇒ Types::Status
The current status of the entity.
-
#update_date_time ⇒ Time
The last date and time when the entity was updated.
Instance Attribute Details
#arn ⇒ String
The ARN of the entity.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the entity was created.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the entity.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#has_child_entities ⇒ Boolean
A Boolean value that specifies whether the entity has child entities or not.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#parent_entity_id ⇒ String
The ID of the parent entity.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The current status of the entity.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The last date and time when the entity was updated.
929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 929 class EntitySummary < Struct.new( :entity_id, :entity_name, :arn, :parent_entity_id, :status, :description, :has_child_entities, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |