Class: Aws::IoTTwinMaker::Types::ExecuteQueryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return at one time. The default is 25.

Valid Range: Minimum value of 1. Maximum value of 250.

Returns:

  • (Integer)


986
987
988
989
990
991
992
993
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 986

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The string that specifies the next page of results.

Returns:

  • (String)


986
987
988
989
990
991
992
993
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 986

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#query_statementString

The query statement.

Returns:

  • (String)


986
987
988
989
990
991
992
993
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 986

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace.

Returns:

  • (String)


986
987
988
989
990
991
992
993
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 986

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end