Class: Aws::IoTTwinMaker::Types::GetComponentTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetComponentTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the component type.
-
#component_type_id ⇒ String
The ID of the component type.
-
#component_type_name ⇒ String
The component type name.
-
#creation_date_time ⇒ Time
The date and time when the component type was created.
-
#description ⇒ String
The description of the component type.
-
#extends_from ⇒ Array<String>
The name of the parent component type that this component type extends.
-
#functions ⇒ Hash<String,Types::FunctionResponse>
An object that maps strings to the functions in the component type.
-
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component type is abstract.
-
#is_schema_initialized ⇒ Boolean
A Boolean value that specifies whether the component type has a schema initializer and that the schema initializer has run.
-
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
-
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionResponse>
An object that maps strings to the property definitions in the component type.
-
#property_groups ⇒ Hash<String,Types::PropertyGroupResponse>
The maximum number of results to return at one time.
-
#status ⇒ Types::Status
The current status of the component type.
-
#sync_source ⇒ String
The syncSource of the SyncJob, if this entity was created by a SyncJob.
-
#update_date_time ⇒ Time
The date and time when the component was last updated.
-
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
Instance Attribute Details
#arn ⇒ String
The ARN of the component type.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#component_type_name ⇒ String
The component type name.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the component type was created.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#extends_from ⇒ Array<String>
The name of the parent component type that this component type extends.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#functions ⇒ Hash<String,Types::FunctionResponse>
An object that maps strings to the functions in the component type. Each string in the mapping must be unique to this object.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component type is abstract.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#is_schema_initialized ⇒ Boolean
A Boolean value that specifies whether the component type has a schema initializer and that the schema initializer has run.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionResponse>
An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#property_groups ⇒ Hash<String,Types::PropertyGroupResponse>
The maximum number of results to return at one time. The default is 25.
Valid Range: Minimum value of 1. Maximum value of 250.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The current status of the component type.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#sync_source ⇒ String
The syncSource of the SyncJob, if this entity was created by a SyncJob.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the component was last updated.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1154 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name) SENSITIVE = [] include Aws::Structure end |