Class: Aws::IoTTwinMaker::Types::GetPropertyValueHistoryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The string that specifies the next page of results.

Returns:

  • (String)


1823
1824
1825
1826
1827
1828
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1823

class GetPropertyValueHistoryResponse < Struct.new(
  :next_token,
  :property_values)
  SENSITIVE = []
  include Aws::Structure
end

#property_valuesArray<Types::PropertyValueHistory>

An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.

Returns:



1823
1824
1825
1826
1827
1828
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1823

class GetPropertyValueHistoryResponse < Struct.new(
  :next_token,
  :property_values)
  SENSITIVE = []
  include Aws::Structure
end