Class: Aws::IoTTwinMaker::Types::GetPropertyValueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component whose property values the operation returns.
-
#component_type_id ⇒ String
The ID of the component type whose property values the operation returns.
-
#entity_id ⇒ String
The ID of the entity whose property values the operation returns.
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#property_group_name ⇒ String
The property group name.
-
#selected_properties ⇒ Array<String>
The properties whose values the operation returns.
-
#tabular_conditions ⇒ Types::TabularConditions
The tabular conditions.
-
#workspace_id ⇒ String
The ID of the workspace whose values the operation returns.
Instance Attribute Details
#component_name ⇒ String
The name of the component whose property values the operation returns.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type whose property values the operation returns.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity whose property values the operation returns.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return at one time. The default is 25.
Valid Range: Minimum value of 1. Maximum value of 250.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The string that specifies the next page of results.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#property_group_name ⇒ String
The property group name.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#selected_properties ⇒ Array<String>
The properties whose values the operation returns.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#tabular_conditions ⇒ Types::TabularConditions
The tabular conditions.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace whose values the operation returns.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1428 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id, :max_results, :next_token, :property_group_name, :tabular_conditions) SENSITIVE = [] include Aws::Structure end |