Class: Aws::IoTTwinMaker::Types::GetPropertyValueResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The string that specifies the next page of results.



1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1927

class GetPropertyValueResponse < Struct.new(
  :property_values,
  :next_token,
  :tabular_property_values)
  SENSITIVE = []
  include Aws::Structure
end

#property_valuesHash<String,Types::PropertyLatestValue>

An object that maps strings to the properties and latest property values in the response. Each string in the mapping must be unique to this object.



1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1927

class GetPropertyValueResponse < Struct.new(
  :property_values,
  :next_token,
  :tabular_property_values)
  SENSITIVE = []
  include Aws::Structure
end

#tabular_property_valuesArray<Array<Hash<String,Types::DataValue>>>

A table of property values.



1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1927

class GetPropertyValueResponse < Struct.new(
  :property_values,
  :next_token,
  :tabular_property_values)
  SENSITIVE = []
  include Aws::Structure
end