Class: Aws::IoTTwinMaker::Types::GetSceneResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetSceneResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the scene.
-
#capabilities ⇒ Array<String>
A list of capabilities that the scene uses to render.
-
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
-
#creation_date_time ⇒ Time
The date and time when the scene was created.
-
#description ⇒ String
The description of the scene.
-
#generated_scene_metadata ⇒ Hash<String,String>
The generated scene metadata.
-
#scene_id ⇒ String
The ID of the scene.
-
#scene_metadata ⇒ Hash<String,String>
The response metadata.
-
#update_date_time ⇒ Time
The date and time when the scene was last updated.
-
#workspace_id ⇒ String
The ID of the workspace that contains the scene.
Instance Attribute Details
#arn ⇒ String
The ARN of the scene.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Array<String>
A list of capabilities that the scene uses to render.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the scene was created.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the scene.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#generated_scene_metadata ⇒ Hash<String,String>
The generated scene metadata.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#scene_id ⇒ String
The ID of the scene.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#scene_metadata ⇒ Hash<String,String>
The response metadata.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the scene was last updated.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the scene.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1520 class GetSceneResponse < Struct.new( :workspace_id, :scene_id, :content_location, :arn, :creation_date_time, :update_date_time, :description, :capabilities, :scene_metadata, :generated_scene_metadata) SENSITIVE = [] include Aws::Structure end |