Class: Aws::IoTTwinMaker::Types::GetWorkspaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetWorkspaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the workspace.
-
#creation_date_time ⇒ Time
The date and time when the workspace was created.
-
#description ⇒ String
The description of the workspace.
-
#role ⇒ String
The ARN of the execution role associated with the workspace.
-
#s3_location ⇒ String
The ARN of the S3 bucket where resources associated with the workspace are stored.
-
#update_date_time ⇒ Time
The date and time when the workspace was last updated.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#arn ⇒ String
The ARN of the workspace.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1620 class GetWorkspaceResponse < Struct.new( :workspace_id, :arn, :description, :s3_location, :role, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the workspace was created.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1620 class GetWorkspaceResponse < Struct.new( :workspace_id, :arn, :description, :s3_location, :role, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the workspace.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1620 class GetWorkspaceResponse < Struct.new( :workspace_id, :arn, :description, :s3_location, :role, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The ARN of the execution role associated with the workspace.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1620 class GetWorkspaceResponse < Struct.new( :workspace_id, :arn, :description, :s3_location, :role, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#s3_location ⇒ String
The ARN of the S3 bucket where resources associated with the workspace are stored.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1620 class GetWorkspaceResponse < Struct.new( :workspace_id, :arn, :description, :s3_location, :role, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the workspace was last updated.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1620 class GetWorkspaceResponse < Struct.new( :workspace_id, :arn, :description, :s3_location, :role, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1620 class GetWorkspaceResponse < Struct.new( :workspace_id, :arn, :description, :s3_location, :role, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |