Class: Aws::IoTTwinMaker::Types::PricingPlan

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

The pricing plan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billable_entity_countInteger

The billable entity count.

Returns:

  • (Integer)


2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2769

class PricingPlan < Struct.new(
  :billable_entity_count,
  :bundle_information,
  :effective_date_time,
  :pricing_mode,
  :update_date_time,
  :update_reason)
  SENSITIVE = []
  include Aws::Structure
end

#bundle_informationTypes::BundleInformation

The pricing plan's bundle information.



2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2769

class PricingPlan < Struct.new(
  :billable_entity_count,
  :bundle_information,
  :effective_date_time,
  :pricing_mode,
  :update_date_time,
  :update_reason)
  SENSITIVE = []
  include Aws::Structure
end

#effective_date_timeTime

The effective date and time of the pricing plan.

Returns:

  • (Time)


2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2769

class PricingPlan < Struct.new(
  :billable_entity_count,
  :bundle_information,
  :effective_date_time,
  :pricing_mode,
  :update_date_time,
  :update_reason)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_modeString

The pricing mode.

Returns:

  • (String)


2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2769

class PricingPlan < Struct.new(
  :billable_entity_count,
  :bundle_information,
  :effective_date_time,
  :pricing_mode,
  :update_date_time,
  :update_reason)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The set date and time for updating a pricing plan.

Returns:

  • (Time)


2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2769

class PricingPlan < Struct.new(
  :billable_entity_count,
  :bundle_information,
  :effective_date_time,
  :pricing_mode,
  :update_date_time,
  :update_reason)
  SENSITIVE = []
  include Aws::Structure
end

#update_reasonString

The update reason, for changing a pricing plan.

Returns:

  • (String)


2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2769

class PricingPlan < Struct.new(
  :billable_entity_count,
  :bundle_information,
  :effective_date_time,
  :pricing_mode,
  :update_date_time,
  :update_reason)
  SENSITIVE = []
  include Aws::Structure
end