Class: Aws::IoTTwinMaker::Types::PropertyDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that contains response data from a property definition request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property.
-
#data_type ⇒ Types::DataType
An object that contains information about the data type.
-
#default_value ⇒ Types::DataValue
An object that contains the default value.
-
#display_name ⇒ String
A friendly name for the property.
-
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
-
#is_final ⇒ Boolean
A Boolean value that specifies whether the property definition can be updated.
-
#is_imported ⇒ Boolean
A Boolean value that specifies whether the property definition is imported from an external data store.
-
#is_inherited ⇒ Boolean
A Boolean value that specifies whether the property definition is inherited from a parent entity.
-
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required in an entity.
-
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
-
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
Instance Attribute Details
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ Types::DataType
An object that contains information about the data type.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ Types::DataValue
An object that contains the default value.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
A friendly name for the property.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_final ⇒ Boolean
A Boolean value that specifies whether the property definition can be updated.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_imported ⇒ Boolean
A Boolean value that specifies whether the property definition is imported from an external data store.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_inherited ⇒ Boolean
A Boolean value that specifies whether the property definition is inherited from a parent entity.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required in an entity.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2241 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |