Class: Aws::IoTTwinMaker::Types::PropertyGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
The property group response
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_type ⇒ String
The group types.
-
#is_inherited ⇒ Boolean
A Boolean value that specifies whether the property group is inherited from a parent entity.
-
#property_names ⇒ Array<String>
The names of properties.
Instance Attribute Details
#group_type ⇒ String
The group types.
3051 3052 3053 3054 3055 3056 3057 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3051 class PropertyGroupResponse < Struct.new( :group_type, :property_names, :is_inherited) SENSITIVE = [] include Aws::Structure end |
#is_inherited ⇒ Boolean
A Boolean value that specifies whether the property group is inherited from a parent entity
3051 3052 3053 3054 3055 3056 3057 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3051 class PropertyGroupResponse < Struct.new( :group_type, :property_names, :is_inherited) SENSITIVE = [] include Aws::Structure end |
#property_names ⇒ Array<String>
The names of properties.
3051 3052 3053 3054 3055 3056 3057 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3051 class PropertyGroupResponse < Struct.new( :group_type, :property_names, :is_inherited) SENSITIVE = [] include Aws::Structure end |