Class: Aws::IoTTwinMaker::Types::PropertyValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that contains information about a value for a time series property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#time ⇒ String
ISO8601 DateTime of a value for a time series property.
-
#timestamp ⇒ Time
The timestamp of a value for a time series property.
-
#value ⇒ Types::DataValue
An object that specifies a value for a time series property.
Instance Attribute Details
#time ⇒ String
ISO8601 DateTime of a value for a time series property.
The time for when the property value was recorded in ISO 8601 format: YYYY-MM-DDThh:mm:ss[.SSSSSSSSS][Z/±HH:mm].
-
[YYYY]: year
-
[MM]: month
-
[DD]: day
-
[hh]: hour
-
[mm]: minute
-
[ss]: seconds
-
[.SSSSSSSSS]: additional precision, where precedence is maintained. For example: [.573123] is equal to 573123000 nanoseconds.
-
Z: default timezone UTC
-
± HH:mm: time zone offset in Hours and Minutes.
Required sub-fields: YYYY-MM-DDThh:mm:ss and [Z/±HH:mm]
3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3286 class PropertyValue < Struct.new( :timestamp, :value, :time) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The timestamp of a value for a time series property.
3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3286 class PropertyValue < Struct.new( :timestamp, :value, :time) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Types::DataValue
An object that specifies a value for a time series property.
3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3286 class PropertyValue < Struct.new( :timestamp, :value, :time) SENSITIVE = [] include Aws::Structure end |