Class: Aws::IoTTwinMaker::Types::PropertyValueEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyValueEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass PropertyValueEntry data as a hash:
{
entity_property_reference: { # required
component_name: "Name",
external_id_property: {
"String" => "String",
},
entity_id: "EntityId",
property_name: "Name", # required
},
property_values: [
{
timestamp: Time.now,
value: { # required
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: [
{
# recursive DataValue
},
],
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
time: "Time",
},
],
}
An object that specifies information about time series property values. This object is used and consumed by the
- BatchPutPropertyValues][1
-
action.
[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_BatchPutPropertyValues.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity_property_reference ⇒ Types::EntityPropertyReference
An object that contains information about the entity that has the property.
-
#property_values ⇒ Array<Types::PropertyValue>
A list of objects that specify time series property values.
Instance Attribute Details
#entity_property_reference ⇒ Types::EntityPropertyReference
An object that contains information about the entity that has the property.
3345 3346 3347 3348 3349 3350 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3345 class PropertyValueEntry < Struct.new( :entity_property_reference, :property_values) SENSITIVE = [] include Aws::Structure end |
#property_values ⇒ Array<Types::PropertyValue>
A list of objects that specify time series property values.
3345 3346 3347 3348 3349 3350 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3345 class PropertyValueEntry < Struct.new( :entity_property_reference, :property_values) SENSITIVE = [] include Aws::Structure end |