Class: Aws::IoTTwinMaker::Types::PropertyValueHistory

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

The history of values for a time series property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entity_property_referenceTypes::EntityPropertyReference

An object that uniquely identifies an entity property.



3363
3364
3365
3366
3367
3368
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3363

class PropertyValueHistory < Struct.new(
  :entity_property_reference,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<Types::PropertyValue>

A list of objects that contain information about the values in the history of a time series property.

Returns:



3363
3364
3365
3366
3367
3368
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3363

class PropertyValueHistory < Struct.new(
  :entity_property_reference,
  :values)
  SENSITIVE = []
  include Aws::Structure
end