Class: Aws::IoTTwinMaker::Types::Relationship

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass Relationship data as a hash:

{
  relationship_type: "String",
  target_component_type_id: "ComponentTypeId",
}

An object that specifies a relationship with another component type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#relationship_typeString

The type of the relationship.

Returns:

  • (String)


2976
2977
2978
2979
2980
2981
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2976

class Relationship < Struct.new(
  :relationship_type,
  :target_component_type_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_component_type_idString

The ID of the target component type associated with this relationship.

Returns:

  • (String)


2976
2977
2978
2979
2980
2981
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2976

class Relationship < Struct.new(
  :relationship_type,
  :target_component_type_id)
  SENSITIVE = []
  include Aws::Structure
end