Class: Aws::IoTTwinMaker::Types::RelationshipValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

A value that associates a component and an entity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#target_component_nameString

The name of the target component associated with the relationship value.

Returns:

  • (String)


2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2503

class RelationshipValue < Struct.new(
  :target_entity_id,
  :target_component_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_entity_idString

The ID of the target entity associated with this relationship value.

Returns:

  • (String)


2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2503

class RelationshipValue < Struct.new(
  :target_entity_id,
  :target_component_name)
  SENSITIVE = []
  include Aws::Structure
end