Class: Aws::IoTTwinMaker::Types::SceneSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

An object that contains information about a scene.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the scene.

Returns:

  • (String)


2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2582

class SceneSummary < Struct.new(
  :scene_id,
  :content_location,
  :arn,
  :creation_date_time,
  :update_date_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#content_locationString

The relative path that specifies the location of the content definition file.

Returns:

  • (String)


2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2582

class SceneSummary < Struct.new(
  :scene_id,
  :content_location,
  :arn,
  :creation_date_time,
  :update_date_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the scene was created.

Returns:

  • (Time)


2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2582

class SceneSummary < Struct.new(
  :scene_id,
  :content_location,
  :arn,
  :creation_date_time,
  :update_date_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The scene description.

Returns:

  • (String)


2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2582

class SceneSummary < Struct.new(
  :scene_id,
  :content_location,
  :arn,
  :creation_date_time,
  :update_date_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#scene_idString

The ID of the scene.

Returns:

  • (String)


2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2582

class SceneSummary < Struct.new(
  :scene_id,
  :content_location,
  :arn,
  :creation_date_time,
  :update_date_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The date and time when the scene was last updated.

Returns:

  • (Time)


2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2582

class SceneSummary < Struct.new(
  :scene_id,
  :content_location,
  :arn,
  :creation_date_time,
  :update_date_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end