Class: Aws::IoTTwinMaker::Types::Status

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

An object that represents the status of an entity, component, component type, or workspace.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::ErrorDetails

The error message.

Returns:



2616
2617
2618
2619
2620
2621
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2616

class Status < Struct.new(
  :state,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the entity, component, component type, or workspace.

Returns:

  • (String)


2616
2617
2618
2619
2620
2621
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2616

class Status < Struct.new(
  :state,
  :error)
  SENSITIVE = []
  include Aws::Structure
end