Class: Aws::IoTTwinMaker::Types::TabularConditions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass TabularConditions data as a hash:

{
  order_by: [
    {
      order: "ASCENDING", # accepts ASCENDING, DESCENDING
      property_name: "String", # required
    },
  ],
  property_filters: [
    {
      property_name: "String",
      operator: "String",
      value: {
        boolean_value: false,
        double_value: 1.0,
        integer_value: 1,
        long_value: 1,
        string_value: "String",
        list_value: [
          {
            # recursive DataValue
          },
        ],
        map_value: {
          "String" => {
            # recursive DataValue
          },
        },
        relationship_value: {
          target_entity_id: "EntityId",
          target_component_name: "Name",
        },
        expression: "Expression",
      },
    },
  ],
}

The tabular conditions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#order_byArray<Types::OrderBy>

Filter criteria that orders the output. It can be sorted in ascending or descending order.

Returns:



3578
3579
3580
3581
3582
3583
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3578

class TabularConditions < Struct.new(
  :order_by,
  :property_filters)
  SENSITIVE = []
  include Aws::Structure
end

#property_filtersArray<Types::PropertyFilter>

You can filter the request using various logical operators and a key-value format. For example:

`“serverType”, “value”: “webServer”`

Returns:



3578
3579
3580
3581
3582
3583
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3578

class TabularConditions < Struct.new(
  :order_by,
  :property_filters)
  SENSITIVE = []
  include Aws::Structure
end