Class: Aws::IoTTwinMaker::Types::UpdateComponentTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateComponentTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type.
-
#component_type_name ⇒ String
The component type name.
-
#description ⇒ String
The description of the component type.
-
#extends_from ⇒ Array<String>
Specifies the component type that this component type extends.
-
#functions ⇒ Hash<String,Types::FunctionRequest>
An object that maps strings to the functions in the component type.
-
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
-
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionRequest>
An object that maps strings to the property definitions in the component type.
-
#property_groups ⇒ Hash<String,Types::PropertyGroupRequest>
The property groups.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#component_type_name ⇒ String
The component type name.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#extends_from ⇒ Array<String>
Specifies the component type that this component type extends.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#functions ⇒ Hash<String,Types::FunctionRequest>
An object that maps strings to the functions in the component type. Each string in the mapping must be unique to this object.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionRequest>
An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#property_groups ⇒ Hash<String,Types::PropertyGroupRequest>
The property groups.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2882 class UpdateComponentTypeRequest < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :property_groups, :component_type_name) SENSITIVE = [] include Aws::Structure end |