Class: Aws::IoTTwinMaker::Types::UpdateComponentTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateComponentTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the component type.
-
#component_type_id ⇒ String
The ID of the component type.
-
#state ⇒ String
The current state of the component type.
-
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
Instance Attribute Details
#arn ⇒ String
The ARN of the component type.
3821 3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3821 class UpdateComponentTypeResponse < Struct.new( :workspace_id, :arn, :component_type_id, :state) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
3821 3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3821 class UpdateComponentTypeResponse < Struct.new( :workspace_id, :arn, :component_type_id, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the component type.
3821 3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3821 class UpdateComponentTypeResponse < Struct.new( :workspace_id, :arn, :component_type_id, :state) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
3821 3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3821 class UpdateComponentTypeResponse < Struct.new( :workspace_id, :arn, :component_type_id, :state) SENSITIVE = [] include Aws::Structure end |