Class: Aws::IoTTwinMaker::Types::UpdateEntityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateEntityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The current state of the entity update.
-
#update_date_time ⇒ Time
The date and time when the entity was last updated.
Instance Attribute Details
#state ⇒ String
The current state of the entity update.
2943 2944 2945 2946 2947 2948 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2943 class UpdateEntityResponse < Struct.new( :update_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the entity was last updated.
2943 2944 2945 2946 2947 2948 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2943 class UpdateEntityResponse < Struct.new( :update_date_time, :state) SENSITIVE = [] include Aws::Structure end |