Class: Aws::IoTTwinMaker::Types::UpdateSceneResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateSceneResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#update_date_time ⇒ Time
The date and time when the scene was last updated.
Instance Attribute Details
#update_date_time ⇒ Time
The date and time when the scene was last updated.
3451 3452 3453 3454 3455 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3451 class UpdateSceneResponse < Struct.new( :update_date_time) SENSITIVE = [] include Aws::Structure end |