Class: Aws::IoTTwinMaker::Types::UpdateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass UpdateWorkspaceRequest data as a hash:
{
workspace_id: "Id", # required
description: "Description",
role: "RoleArn",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the workspace.
-
#role ⇒ String
The ARN of the execution role associated with the workspace.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#description ⇒ String
The description of the workspace.
4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 4111 class UpdateWorkspaceRequest < Struct.new( :workspace_id, :description, :role) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The ARN of the execution role associated with the workspace.
4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 4111 class UpdateWorkspaceRequest < Struct.new( :workspace_id, :description, :role) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 4111 class UpdateWorkspaceRequest < Struct.new( :workspace_id, :description, :role) SENSITIVE = [] include Aws::Structure end |