Class: Aws::IoTTwinMaker::Types::WorkspaceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::WorkspaceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that contains information about a workspace.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the workspace.
-
#creation_date_time ⇒ Time
The date and time when the workspace was created.
-
#description ⇒ String
The description of the workspace.
-
#update_date_time ⇒ Time
The date and time when the workspace was last updated.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#arn ⇒ String
The ARN of the workspace.
3111 3112 3113 3114 3115 3116 3117 3118 3119 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3111 class WorkspaceSummary < Struct.new( :workspace_id, :arn, :description, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the workspace was created.
3111 3112 3113 3114 3115 3116 3117 3118 3119 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3111 class WorkspaceSummary < Struct.new( :workspace_id, :arn, :description, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the workspace.
3111 3112 3113 3114 3115 3116 3117 3118 3119 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3111 class WorkspaceSummary < Struct.new( :workspace_id, :arn, :description, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the workspace was last updated.
3111 3112 3113 3114 3115 3116 3117 3118 3119 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3111 class WorkspaceSummary < Struct.new( :workspace_id, :arn, :description, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
3111 3112 3113 3114 3115 3116 3117 3118 3119 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3111 class WorkspaceSummary < Struct.new( :workspace_id, :arn, :description, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |