Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
-
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
476 477 478 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 476 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3568 3569 3570 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3568 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3571 3572 3573 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3571 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
572 573 574 575 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 572 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3541 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTTwinMaker') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.44.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
612 613 614 615 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 612 def (params = {}, = {}) req = build_request(:cancel_metadata_transfer_job, params) req.send_request() end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
775 776 777 778 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 775 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
1047 1048 1049 1050 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1047 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
1140 1141 1142 1143 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1140 def (params = {}, = {}) req = build_request(:create_metadata_transfer_job, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
1197 1198 1199 1200 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1197 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
1247 1248 1249 1250 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1247 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
1294 1295 1296 1297 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1294 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
1324 1325 1326 1327 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1324 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
1359 1360 1361 1362 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1359 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1383 1384 1385 1386 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1383 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1417 1418 1419 1420 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1417 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
1443 1444 1445 1446 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1443 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
<note markdown=“1”> The ExecuteQuery action only works with [Amazon Web Services Java SDK2]. ExecuteQuery will not work with any Amazon Web Services Java SDK version < 2.x.
</note>
[1]: docs.aws.amazon.com/sdk-for-java/latest/developer-guide/home.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1502 1503 1504 1505 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1502 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1618 1619 1620 1621 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1618 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1757 1758 1759 1760 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1757 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
1826 1827 1828 1829 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1826 def (params = {}, = {}) req = build_request(:get_metadata_transfer_job, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1859 1860 1861 1862 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1859 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either ‘componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2003 2004 2005 2006 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2003 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for ‘workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2164 2165 2166 2167 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2164 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
2218 2219 2220 2221 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2218 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
2266 2267 2268 2269 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2266 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
2307 2308 2309 2310 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2307 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2371 2372 2373 2374 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2371 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2433 2434 2435 2436 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2433 def list_components(params = {}, = {}) req = build_request(:list_components, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2499 2500 2501 2502 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2499 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2562 2563 2564 2565 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2562 def (params = {}, = {}) req = build_request(:list_metadata_transfer_jobs, params) req.send_request() end |
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2668 2669 2670 2671 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2668 def list_properties(params = {}, = {}) req = build_request(:list_properties, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2712 2713 2714 2715 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2712 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2761 2762 2763 2764 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2761 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2836 2837 2838 2839 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2836 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2876 2877 2878 2879 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2876 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2920 2921 2922 2923 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2920 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2946 2947 2948 2949 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2946 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2971 2972 2973 2974 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2971 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
3131 3132 3133 3134 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3131 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
3398 3399 3400 3401 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3398 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
3444 3445 3446 3447 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3444 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
3493 3494 3495 3496 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3493 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
3532 3533 3534 3535 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3532 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3561 3562 3563 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3561 def waiter_names [] end |