Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
-
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
466 467 468 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 466 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3558 3559 3560 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3558 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3561 3562 3563 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3561 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
562 563 564 565 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 562 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 3543 3544 3545 3546 3547 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3531 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTTwinMaker') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.41.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
602 603 604 605 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 602 def (params = {}, = {}) req = build_request(:cancel_metadata_transfer_job, params) req.send_request() end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
765 766 767 768 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 765 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
1037 1038 1039 1040 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1037 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
1130 1131 1132 1133 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1130 def (params = {}, = {}) req = build_request(:create_metadata_transfer_job, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
1187 1188 1189 1190 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1187 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
1237 1238 1239 1240 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1237 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
1284 1285 1286 1287 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1284 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
1314 1315 1316 1317 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1314 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
1349 1350 1351 1352 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1349 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1373 1374 1375 1376 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1373 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1407 1408 1409 1410 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1407 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
1433 1434 1435 1436 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1433 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
<note markdown=“1”> The ExecuteQuery action only works with [Amazon Web Services Java SDK2]. ExecuteQuery will not work with any Amazon Web Services Java SDK version < 2.x.
</note>
[1]: docs.aws.amazon.com/sdk-for-java/latest/developer-guide/home.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1492 1493 1494 1495 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1492 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1608 1609 1610 1611 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1608 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1747 1748 1749 1750 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1747 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
1816 1817 1818 1819 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1816 def (params = {}, = {}) req = build_request(:get_metadata_transfer_job, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1849 1850 1851 1852 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1849 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either ‘componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1993 1994 1995 1996 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1993 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for ‘workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2154 2155 2156 2157 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2154 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
2208 2209 2210 2211 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2208 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
2256 2257 2258 2259 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2256 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
2297 2298 2299 2300 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2297 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2361 2362 2363 2364 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2361 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2423 2424 2425 2426 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2423 def list_components(params = {}, = {}) req = build_request(:list_components, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2489 2490 2491 2492 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2489 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2552 2553 2554 2555 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2552 def (params = {}, = {}) req = build_request(:list_metadata_transfer_jobs, params) req.send_request() end |
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2658 2659 2660 2661 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2658 def list_properties(params = {}, = {}) req = build_request(:list_properties, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2702 2703 2704 2705 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2702 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2751 2752 2753 2754 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2751 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2826 2827 2828 2829 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2826 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2866 2867 2868 2869 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2866 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2910 2911 2912 2913 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2910 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2936 2937 2938 2939 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2936 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2961 2962 2963 2964 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2961 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
3121 3122 3123 3124 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3121 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
3388 3389 3390 3391 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3388 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
3434 3435 3436 3437 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3434 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
3483 3484 3485 3486 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3483 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
3522 3523 3524 3525 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3522 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3551 3552 3553 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3551 def waiter_names [] end |