Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
-
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
440 441 442 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 440 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3532 3533 3534 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3532 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3535 3536 3537 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3535 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
536 537 538 539 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 536 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3505 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTTwinMaker') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.30.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
576 577 578 579 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 576 def (params = {}, = {}) req = build_request(:cancel_metadata_transfer_job, params) req.send_request() end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
739 740 741 742 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 739 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
1011 1012 1013 1014 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1011 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
1104 1105 1106 1107 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1104 def (params = {}, = {}) req = build_request(:create_metadata_transfer_job, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
1161 1162 1163 1164 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1161 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
1211 1212 1213 1214 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1211 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
1258 1259 1260 1261 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1258 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
1288 1289 1290 1291 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1288 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
1323 1324 1325 1326 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1323 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1347 1348 1349 1350 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1347 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1381 1382 1383 1384 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1381 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
1407 1408 1409 1410 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1407 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
<note markdown=“1”> The ExecuteQuery action only works with [Amazon Web Services Java SDK2]. ExecuteQuery will not work with any Amazon Web Services Java SDK version < 2.x.
</note>
[1]: docs.aws.amazon.com/sdk-for-java/latest/developer-guide/home.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1466 1467 1468 1469 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1466 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1582 1583 1584 1585 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1582 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1721 1722 1723 1724 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1721 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
1790 1791 1792 1793 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1790 def (params = {}, = {}) req = build_request(:get_metadata_transfer_job, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1823 1824 1825 1826 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1823 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either ‘componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1967 1968 1969 1970 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1967 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for ‘workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2128 2129 2130 2131 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2128 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
2182 2183 2184 2185 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2182 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
2230 2231 2232 2233 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2230 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
2271 2272 2273 2274 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2271 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2335 2336 2337 2338 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2335 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2397 2398 2399 2400 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2397 def list_components(params = {}, = {}) req = build_request(:list_components, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2463 2464 2465 2466 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2463 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2526 2527 2528 2529 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2526 def (params = {}, = {}) req = build_request(:list_metadata_transfer_jobs, params) req.send_request() end |
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2632 2633 2634 2635 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2632 def list_properties(params = {}, = {}) req = build_request(:list_properties, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2676 2677 2678 2679 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2676 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2725 2726 2727 2728 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2725 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2800 2801 2802 2803 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2800 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2840 2841 2842 2843 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2840 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2884 2885 2886 2887 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2884 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2910 2911 2912 2913 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2910 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2935 2936 2937 2938 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2935 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
3095 3096 3097 3098 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3095 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
3362 3363 3364 3365 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3362 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
3408 3409 3410 3411 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3408 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
3457 3458 3459 3460 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3457 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
3496 3497 3498 3499 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3496 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3525 3526 3527 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3525 def waiter_names [] end |