Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
-
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
410 411 412 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 410 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3497 3498 3499 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3497 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3500 3501 3502 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3500 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
506 507 508 509 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 506 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3475 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.25.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
546 547 548 549 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 546 def (params = {}, = {}) req = build_request(:cancel_metadata_transfer_job, params) req.send_request() end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
709 710 711 712 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 709 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
981 982 983 984 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 981 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
1074 1075 1076 1077 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1074 def (params = {}, = {}) req = build_request(:create_metadata_transfer_job, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
1131 1132 1133 1134 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1131 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
1181 1182 1183 1184 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1181 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
1228 1229 1230 1231 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1228 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
1258 1259 1260 1261 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1258 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
1293 1294 1295 1296 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1293 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1317 1318 1319 1320 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1317 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1351 1352 1353 1354 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1351 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
1377 1378 1379 1380 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1377 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
<note markdown=“1”> The ExecuteQuery action only works with [Amazon Web Services Java SDK2]. ExecuteQuery will not work with any Amazon Web Services Java SDK version < 2.x.
</note>
[1]: docs.aws.amazon.com/sdk-for-java/latest/developer-guide/home.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1436 1437 1438 1439 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1436 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1552 1553 1554 1555 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1552 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1691 1692 1693 1694 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1691 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
1760 1761 1762 1763 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1760 def (params = {}, = {}) req = build_request(:get_metadata_transfer_job, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1793 1794 1795 1796 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1793 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either ‘componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1937 1938 1939 1940 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1937 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for ‘workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2098 2099 2100 2101 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2098 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
2152 2153 2154 2155 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2152 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
2200 2201 2202 2203 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2200 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
2241 2242 2243 2244 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2241 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2305 2306 2307 2308 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2305 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2367 2368 2369 2370 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2367 def list_components(params = {}, = {}) req = build_request(:list_components, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2433 2434 2435 2436 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2433 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2496 2497 2498 2499 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2496 def (params = {}, = {}) req = build_request(:list_metadata_transfer_jobs, params) req.send_request() end |
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2602 2603 2604 2605 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2602 def list_properties(params = {}, = {}) req = build_request(:list_properties, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2646 2647 2648 2649 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2646 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2695 2696 2697 2698 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2695 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2770 2771 2772 2773 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2770 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2810 2811 2812 2813 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2810 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2854 2855 2856 2857 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2854 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2880 2881 2882 2883 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2880 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2905 2906 2907 2908 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2905 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
3065 3066 3067 3068 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3065 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
3332 3333 3334 3335 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3332 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
3378 3379 3380 3381 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3378 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
3427 3428 3429 3430 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3427 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
3466 3467 3468 3469 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3466 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3490 3491 3492 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3490 def waiter_names [] end |