Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
-
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
385 386 387 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 385 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3472 3473 3474 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3472 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3475 3476 3477 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3475 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
481 482 483 484 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 481 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3450 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.18.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_metadata_transfer_job(params = {}) ⇒ Types::CancelMetadataTransferJobResponse
Cancels the metadata transfer job.
521 522 523 524 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 521 def (params = {}, = {}) req = build_request(:cancel_metadata_transfer_job, params) req.send_request() end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
684 685 686 687 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 684 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
956 957 958 959 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 956 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_metadata_transfer_job(params = {}) ⇒ Types::CreateMetadataTransferJobResponse
Creates a new metadata transfer job.
1049 1050 1051 1052 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1049 def (params = {}, = {}) req = build_request(:create_metadata_transfer_job, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
1106 1107 1108 1109 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1106 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
1156 1157 1158 1159 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1156 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
1203 1204 1205 1206 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1203 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
1233 1234 1235 1236 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1233 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
1268 1269 1270 1271 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1268 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1292 1293 1294 1295 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1292 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1326 1327 1328 1329 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1326 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes a workspace.
1352 1353 1354 1355 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1352 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
<note markdown=“1”> The ExecuteQuery action only works with [Amazon Web Services Java SDK2]. ExecuteQuery will not work with any Amazon Web Services Java SDK version < 2.x.
</note>
[1]: docs.aws.amazon.com/sdk-for-java/latest/developer-guide/home.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1411 1412 1413 1414 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1411 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1527 1528 1529 1530 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1527 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1666 1667 1668 1669 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1666 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_metadata_transfer_job(params = {}) ⇒ Types::GetMetadataTransferJobResponse
Gets a nmetadata transfer job.
1735 1736 1737 1738 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1735 def (params = {}, = {}) req = build_request(:get_metadata_transfer_job, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1768 1769 1770 1771 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1768 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either ‘componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1912 1913 1914 1915 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1912 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for ‘workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2073 2074 2075 2076 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2073 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
2127 2128 2129 2130 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2127 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
2175 2176 2177 2178 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2175 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
2216 2217 2218 2219 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2216 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2280 2281 2282 2283 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2280 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_components(params = {}) ⇒ Types::ListComponentsResponse
This API lists the components of an entity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2342 2343 2344 2345 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2342 def list_components(params = {}, = {}) req = build_request(:list_components, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2408 2409 2410 2411 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2408 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_metadata_transfer_jobs(params = {}) ⇒ Types::ListMetadataTransferJobsResponse
Lists the metadata transfer jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2471 2472 2473 2474 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2471 def (params = {}, = {}) req = build_request(:list_metadata_transfer_jobs, params) req.send_request() end |
#list_properties(params = {}) ⇒ Types::ListPropertiesResponse
This API lists the properties of a component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2577 2578 2579 2580 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2577 def list_properties(params = {}, = {}) req = build_request(:list_properties, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2621 2622 2623 2624 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2621 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2670 2671 2672 2673 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2670 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2745 2746 2747 2748 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2745 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2785 2786 2787 2788 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2785 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2829 2830 2831 2832 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2829 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2855 2856 2857 2858 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2855 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2880 2881 2882 2883 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2880 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
3040 3041 3042 3043 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3040 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
3307 3308 3309 3310 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3307 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
3353 3354 3355 3356 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3353 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
3402 3403 3404 3405 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3402 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
3441 3442 3443 3444 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3441 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3465 3466 3467 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 3465 def waiter_names [] end |