Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
381 382 383 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 381 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2734 2735 2736 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2734 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2737 2738 2739 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2737 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
475 476 477 478 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 475 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2712 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.15.0' Seahorse::Client::Request.new(handlers, context) end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
628 629 630 631 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 628 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
791 792 793 794 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 791 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
848 849 850 851 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 848 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
898 899 900 901 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 898 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
945 946 947 948 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 945 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
975 976 977 978 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 975 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
1010 1011 1012 1013 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1010 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1034 1035 1036 1037 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1034 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1068 1069 1070 1071 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1068 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
1088 1089 1090 1091 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1088 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1139 1140 1141 1142 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1139 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1251 1252 1253 1254 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1251 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1370 1371 1372 1373 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1370 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1403 1404 1405 1406 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1403 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either ‘componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1541 1542 1543 1544 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1541 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for ‘workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1696 1697 1698 1699 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1696 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
1750 1751 1752 1753 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1750 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
1798 1799 1800 1801 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1798 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
1836 1837 1838 1839 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1836 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1900 1901 1902 1903 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1900 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1966 1967 1968 1969 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1966 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2010 2011 2012 2013 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2010 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2059 2060 2061 2062 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2059 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2134 2135 2136 2137 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2134 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2174 2175 2176 2177 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2174 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2216 2217 2218 2219 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2216 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2242 2243 2244 2245 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2242 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2267 2268 2269 2270 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2267 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
2417 2418 2419 2420 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2417 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
2574 2575 2576 2577 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2574 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
2620 2621 2622 2623 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2620 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
2669 2670 2671 2672 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2669 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
2703 2704 2705 2706 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2703 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2727 2728 2729 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2727 def waiter_names [] end |