Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2718 2719 2720 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2718 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2721 2722 2723 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2721 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
459 460 461 462 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 459 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2696 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.11.0' Seahorse::Client::Request.new(handlers, context) end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
612 613 614 615 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 612 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
775 776 777 778 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 775 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
832 833 834 835 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 832 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
882 883 884 885 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 882 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
929 930 931 932 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 929 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
959 960 961 962 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 959 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
994 995 996 997 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 994 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1018 1019 1020 1021 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1018 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1052 1053 1054 1055 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1052 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
1072 1073 1074 1075 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1072 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1123 1124 1125 1126 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1123 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1235 1236 1237 1238 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1235 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1354 1355 1356 1357 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1354 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1387 1388 1389 1390 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1387 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either ‘componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1525 1526 1527 1528 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1525 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for ‘workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1680 1681 1682 1683 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1680 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
1734 1735 1736 1737 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1734 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
1782 1783 1784 1785 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1782 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
1820 1821 1822 1823 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1820 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1884 1885 1886 1887 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1884 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1950 1951 1952 1953 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1950 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1994 1995 1996 1997 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1994 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2043 2044 2045 2046 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2043 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2118 2119 2120 2121 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2118 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2158 2159 2160 2161 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2158 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2200 2201 2202 2203 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2200 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2226 2227 2228 2229 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2226 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2251 2252 2253 2254 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2251 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
2401 2402 2403 2404 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2401 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
2558 2559 2560 2561 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2558 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
2604 2605 2606 2607 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2604 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
2653 2654 2655 2656 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2653 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
2687 2688 2689 2690 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2687 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2711 2712 2713 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2711 def waiter_names [] end |