Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
-
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
-
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2689 2690 2691 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2689 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2692 2693 2694 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2692 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
459 460 461 462 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 459 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2667 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.9.0' Seahorse::Client::Request.new(handlers, context) end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
612 613 614 615 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 612 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
775 776 777 778 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 775 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
826 827 828 829 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 826 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_sync_job(params = {}) ⇒ Types::CreateSyncJobResponse
This action creates a SyncJob.
876 877 878 879 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 876 def create_sync_job(params = {}, = {}) req = build_request(:create_sync_job, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
923 924 925 926 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 923 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
953 954 955 956 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 953 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
988 989 990 991 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 988 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
1012 1013 1014 1015 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1012 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_sync_job(params = {}) ⇒ Types::DeleteSyncJobResponse
Delete the SyncJob.
1046 1047 1048 1049 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1046 def delete_sync_job(params = {}, = {}) req = build_request(:delete_sync_job, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
1066 1067 1068 1069 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1066 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1117 1118 1119 1120 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1117 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1229 1230 1231 1232 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1229 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1348 1349 1350 1351 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1348 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1381 1382 1383 1384 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1381 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either `componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1519 1520 1521 1522 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1519 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for `workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1674 1675 1676 1677 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1674 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
1719 1720 1721 1722 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1719 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_sync_job(params = {}) ⇒ Types::GetSyncJobResponse
Gets the SyncJob.
1767 1768 1769 1770 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1767 def get_sync_job(params = {}, = {}) req = build_request(:get_sync_job, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
1805 1806 1807 1808 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1805 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1869 1870 1871 1872 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1869 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1935 1936 1937 1938 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1935 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1979 1980 1981 1982 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1979 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_sync_jobs(params = {}) ⇒ Types::ListSyncJobsResponse
List all SyncJobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2028 def list_sync_jobs(params = {}, = {}) req = build_request(:list_sync_jobs, params) req.send_request() end |
#list_sync_resources(params = {}) ⇒ Types::ListSyncResourcesResponse
Lists the sync resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2095 2096 2097 2098 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2095 def list_sync_resources(params = {}, = {}) req = build_request(:list_sync_resources, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
2135 2136 2137 2138 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2135 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2177 2178 2179 2180 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2177 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2203 2204 2205 2206 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2203 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2228 2229 2230 2231 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2228 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
2378 2379 2380 2381 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2378 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
2535 2536 2537 2538 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2535 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
2581 2582 2583 2584 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2581 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
2624 2625 2626 2627 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2624 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
2658 2659 2660 2661 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2658 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2682 2683 2684 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2682 def waiter_names [] end |