Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2419 2420 2421 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2419 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2422 2423 2424 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2422 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
459 460 461 462 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 459 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2397 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.7.0' Seahorse::Client::Request.new(handlers, context) end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
607 608 609 610 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 607 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
769 770 771 772 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 769 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
820 821 822 823 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 820 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
867 868 869 870 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 867 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
897 898 899 900 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 897 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
932 933 934 935 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 932 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
956 957 958 959 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 956 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
976 977 978 979 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 976 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryResponse
Run queries to access information from your knowledge graph of entities within individual workspaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1027 1028 1029 1030 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1027 def execute_query(params = {}, = {}) req = build_request(:execute_query, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1134 1135 1136 1137 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1134 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1249 1250 1251 1252 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1249 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_pricing_plan(params = {}) ⇒ Types::GetPricingPlanResponse
Gets the pricing plan.
1282 1283 1284 1285 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1282 def get_pricing_plan(params = {}, = {}) req = build_request(:get_pricing_plan, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either `componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1420 1421 1422 1423 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1420 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for `workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1575 1576 1577 1578 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1575 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
1620 1621 1622 1623 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1620 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
1658 1659 1660 1661 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1658 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1721 1722 1723 1724 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1721 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1787 1788 1789 1790 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1787 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1831 1832 1833 1834 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1831 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
1871 1872 1873 1874 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1871 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1913 1914 1915 1916 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1913 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
1939 1940 1941 1942 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1939 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
1964 1965 1966 1967 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1964 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
2109 2110 2111 2112 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2109 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
2265 2266 2267 2268 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2265 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanResponse
Update the pricing plan.
2311 2312 2313 2314 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2311 def update_pricing_plan(params = {}, = {}) req = build_request(:update_pricing_plan, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
2354 2355 2356 2357 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2354 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
2388 2389 2390 2391 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2388 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2412 2413 2414 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2412 def waiter_names [] end |