Class: Aws::IoTTwinMaker::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTTwinMaker::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iottwinmaker/client.rb
Overview
An API client for IoTTwinMaker. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::IoTTwinMaker::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
-
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
-
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
-
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
-
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
-
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
-
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
-
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
-
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
-
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
-
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
-
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
-
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
-
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
-
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
-
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
-
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
-
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
-
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2158 2159 2160 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2158 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2161 2162 2163 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2161 def errors_module Errors end |
Instance Method Details
#batch_put_property_values(params = {}) ⇒ Types::BatchPutPropertyValuesResponse
Sets values for multiple time series properties.
459 460 461 462 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 459 def batch_put_property_values(params = {}, = {}) req = build_request(:batch_put_property_values, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2136 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iottwinmaker' context[:gem_version] = '1.6.0' Seahorse::Client::Request.new(handlers, context) end |
#create_component_type(params = {}) ⇒ Types::CreateComponentTypeResponse
Creates a component type.
599 600 601 602 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 599 def create_component_type(params = {}, = {}) req = build_request(:create_component_type, params) req.send_request() end |
#create_entity(params = {}) ⇒ Types::CreateEntityResponse
Creates an entity.
754 755 756 757 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 754 def create_entity(params = {}, = {}) req = build_request(:create_entity, params) req.send_request() end |
#create_scene(params = {}) ⇒ Types::CreateSceneResponse
Creates a scene.
805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 805 def create_scene(params = {}, = {}) req = build_request(:create_scene, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workplace.
852 853 854 855 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 852 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_component_type(params = {}) ⇒ Types::DeleteComponentTypeResponse
Deletes a component type.
882 883 884 885 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 882 def delete_component_type(params = {}, = {}) req = build_request(:delete_component_type, params) req.send_request() end |
#delete_entity(params = {}) ⇒ Types::DeleteEntityResponse
Deletes an entity.
917 918 919 920 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 917 def delete_entity(params = {}, = {}) req = build_request(:delete_entity, params) req.send_request() end |
#delete_scene(params = {}) ⇒ Struct
Deletes a scene.
941 942 943 944 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 941 def delete_scene(params = {}, = {}) req = build_request(:delete_scene, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Struct
Deletes a workspace.
961 962 963 964 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 961 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#get_component_type(params = {}) ⇒ Types::GetComponentTypeResponse
Retrieves information about a component type.
1062 1063 1064 1065 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1062 def get_component_type(params = {}, = {}) req = build_request(:get_component_type, params) req.send_request() end |
#get_entity(params = {}) ⇒ Types::GetEntityResponse
Retrieves information about an entity.
1172 1173 1174 1175 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1172 def get_entity(params = {}, = {}) req = build_request(:get_entity, params) req.send_request() end |
#get_property_value(params = {}) ⇒ Types::GetPropertyValueResponse
Gets the property values for a component, component type, entity, or workspace.
You must specify a value for either `componentName`, `componentTypeId`, `entityId`, or `workspaceId`.
1236 1237 1238 1239 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1236 def get_property_value(params = {}, = {}) req = build_request(:get_property_value, params) req.send_request() end |
#get_property_value_history(params = {}) ⇒ Types::GetPropertyValueHistoryResponse
Retrieves information about the history of a time series property value for a component, component type, entity, or workspace.
You must specify a value for `workspaceId`. For entity-specific queries, specify values for `componentName` and `entityId`. For cross-entity quries, specify a value for `componentTypeId`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1388 1389 1390 1391 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1388 def get_property_value_history(params = {}, = {}) req = build_request(:get_property_value_history, params) req.send_request() end |
#get_scene(params = {}) ⇒ Types::GetSceneResponse
Retrieves information about a scene.
1433 1434 1435 1436 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1433 def get_scene(params = {}, = {}) req = build_request(:get_scene, params) req.send_request() end |
#get_workspace(params = {}) ⇒ Types::GetWorkspaceResponse
Retrieves information about a workspace.
1471 1472 1473 1474 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1471 def get_workspace(params = {}, = {}) req = build_request(:get_workspace, params) req.send_request() end |
#list_component_types(params = {}) ⇒ Types::ListComponentTypesResponse
Lists all component types in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1531 1532 1533 1534 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1531 def list_component_types(params = {}, = {}) req = build_request(:list_component_types, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Lists all entities in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1594 1595 1596 1597 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1594 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_scenes(params = {}) ⇒ Types::ListScenesResponse
Lists all scenes in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1638 1639 1640 1641 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1638 def list_scenes(params = {}, = {}) req = build_request(:list_scenes, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a resource.
1675 1676 1677 1678 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1675 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Retrieves information about workspaces in the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1714 1715 1716 1717 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1714 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
1740 1741 1742 1743 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1740 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
1765 1766 1767 1768 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1765 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_component_type(params = {}) ⇒ Types::UpdateComponentTypeResponse
Updates information in a component type.
1901 1902 1903 1904 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 1901 def update_component_type(params = {}, = {}) req = build_request(:update_component_type, params) req.send_request() end |
#update_entity(params = {}) ⇒ Types::UpdateEntityResponse
Updates an entity.
2050 2051 2052 2053 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2050 def update_entity(params = {}, = {}) req = build_request(:update_entity, params) req.send_request() end |
#update_scene(params = {}) ⇒ Types::UpdateSceneResponse
Updates a scene.
2093 2094 2095 2096 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2093 def update_scene(params = {}, = {}) req = build_request(:update_scene, params) req.send_request() end |
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Updates a workspace.
2127 2128 2129 2130 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2127 def update_workspace(params = {}, = {}) req = build_request(:update_workspace, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2151 2152 2153 |
# File 'lib/aws-sdk-iottwinmaker/client.rb', line 2151 def waiter_names [] end |