Module: Aws::IoTTwinMaker::Types

Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Defined Under Namespace

Classes: AccessDeniedException, BatchPutPropertyError, BatchPutPropertyErrorEntry, BatchPutPropertyValuesRequest, BatchPutPropertyValuesResponse, BundleInformation, ColumnDescription, ComponentPropertyGroupRequest, ComponentPropertyGroupResponse, ComponentRequest, ComponentResponse, ComponentTypeSummary, ComponentUpdateRequest, ConflictException, ConnectorFailureException, ConnectorTimeoutException, CreateComponentTypeRequest, CreateComponentTypeResponse, CreateEntityRequest, CreateEntityResponse, CreateSceneRequest, CreateSceneResponse, CreateSyncJobRequest, CreateSyncJobResponse, CreateWorkspaceRequest, CreateWorkspaceResponse, DataConnector, DataType, DataValue, DeleteComponentTypeRequest, DeleteComponentTypeResponse, DeleteEntityRequest, DeleteEntityResponse, DeleteSceneRequest, DeleteSceneResponse, DeleteSyncJobRequest, DeleteSyncJobResponse, DeleteWorkspaceRequest, DeleteWorkspaceResponse, EntityPropertyReference, EntitySummary, ErrorDetails, ExecuteQueryRequest, ExecuteQueryResponse, FunctionRequest, FunctionResponse, GetComponentTypeRequest, GetComponentTypeResponse, GetEntityRequest, GetEntityResponse, GetPricingPlanRequest, GetPricingPlanResponse, GetPropertyValueHistoryRequest, GetPropertyValueHistoryResponse, GetPropertyValueRequest, GetPropertyValueResponse, GetSceneRequest, GetSceneResponse, GetSyncJobRequest, GetSyncJobResponse, GetWorkspaceRequest, GetWorkspaceResponse, InternalServerException, InterpolationParameters, LambdaFunction, ListComponentTypesFilter, ListComponentTypesRequest, ListComponentTypesResponse, ListEntitiesFilter, ListEntitiesRequest, ListEntitiesResponse, ListScenesRequest, ListScenesResponse, ListSyncJobsRequest, ListSyncJobsResponse, ListSyncResourcesRequest, ListSyncResourcesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListWorkspacesRequest, ListWorkspacesResponse, OrderBy, ParentEntityUpdateRequest, PricingPlan, PropertyDefinitionRequest, PropertyDefinitionResponse, PropertyFilter, PropertyGroupRequest, PropertyGroupResponse, PropertyLatestValue, PropertyRequest, PropertyResponse, PropertyValue, PropertyValueEntry, PropertyValueHistory, QueryTimeoutException, Relationship, RelationshipValue, ResourceNotFoundException, Row, SceneSummary, ServiceQuotaExceededException, Status, SyncJobStatus, SyncJobSummary, SyncResourceFilter, SyncResourceStatus, SyncResourceSummary, TabularConditions, TagResourceRequest, TagResourceResponse, ThrottlingException, TooManyTagsException, UntagResourceRequest, UntagResourceResponse, UpdateComponentTypeRequest, UpdateComponentTypeResponse, UpdateEntityRequest, UpdateEntityResponse, UpdatePricingPlanRequest, UpdatePricingPlanResponse, UpdateSceneRequest, UpdateSceneResponse, UpdateWorkspaceRequest, UpdateWorkspaceResponse, ValidationException, WorkspaceSummary

Instance Attribute Summary collapse

Instance Attribute Details

#component_type_idString

The ID of the component type in the entities in the list.

Returns:

  • (String)


1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1796

class ListEntitiesFilter < Struct.new(
  :parent_entity_id,
  :component_type_id,
  :external_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ParentEntityId < ListEntitiesFilter; end
  class ComponentTypeId < ListEntitiesFilter; end
  class ExternalId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end

#extends_fromString

The component type that the component types in the list extend.

Returns:

  • (String)


1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1710

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :namespace,
  :is_abstract,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#external_idString

The external ID.

Returns:

  • (String)


1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1796

class ListEntitiesFilter < Struct.new(
  :parent_entity_id,
  :component_type_id,
  :external_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ParentEntityId < ListEntitiesFilter; end
  class ComponentTypeId < ListEntitiesFilter; end
  class ExternalId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end

#is_abstractBoolean

A Boolean value that specifies whether the component types in the list are abstract.

Returns:

  • (Boolean)


1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1710

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :namespace,
  :is_abstract,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#namespaceString

The namespace to which the component types in the list belong.

Returns:

  • (String)


1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1710

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :namespace,
  :is_abstract,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#parent_entity_idString

The parent of the entities in the list.

Returns:

  • (String)


1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1796

class ListEntitiesFilter < Struct.new(
  :parent_entity_id,
  :component_type_id,
  :external_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ParentEntityId < ListEntitiesFilter; end
  class ComponentTypeId < ListEntitiesFilter; end
  class ExternalId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end

#resource_idString

The sync resource filter resource ID.

Returns:

  • (String)


2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2675

class SyncResourceFilter < Struct.new(
  :state,
  :resource_type,
  :resource_id,
  :external_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class State < SyncResourceFilter; end
  class ResourceType < SyncResourceFilter; end
  class ResourceId < SyncResourceFilter; end
  class ExternalId < SyncResourceFilter; end
  class Unknown < SyncResourceFilter; end
end

#resource_typeString

The sync resource filter resource type

Returns:

  • (String)


2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2675

class SyncResourceFilter < Struct.new(
  :state,
  :resource_type,
  :resource_id,
  :external_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class State < SyncResourceFilter; end
  class ResourceType < SyncResourceFilter; end
  class ResourceId < SyncResourceFilter; end
  class ExternalId < SyncResourceFilter; end
  class Unknown < SyncResourceFilter; end
end

#stateString

The sync resource filter’s state.

Returns:

  • (String)


2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2675

class SyncResourceFilter < Struct.new(
  :state,
  :resource_type,
  :resource_id,
  :external_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class State < SyncResourceFilter; end
  class ResourceType < SyncResourceFilter; end
  class ResourceId < SyncResourceFilter; end
  class ExternalId < SyncResourceFilter; end
  class Unknown < SyncResourceFilter; end
end