Module: Aws::IoTTwinMaker::Types
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Defined Under Namespace
Classes: AccessDeniedException, BatchPutPropertyError, BatchPutPropertyErrorEntry, BatchPutPropertyValuesRequest, BatchPutPropertyValuesResponse, BundleInformation, ColumnDescription, ComponentPropertyGroupRequest, ComponentPropertyGroupResponse, ComponentRequest, ComponentResponse, ComponentTypeSummary, ComponentUpdateRequest, ConflictException, ConnectorFailureException, ConnectorTimeoutException, CreateComponentTypeRequest, CreateComponentTypeResponse, CreateEntityRequest, CreateEntityResponse, CreateSceneRequest, CreateSceneResponse, CreateWorkspaceRequest, CreateWorkspaceResponse, DataConnector, DataType, DataValue, DeleteComponentTypeRequest, DeleteComponentTypeResponse, DeleteEntityRequest, DeleteEntityResponse, DeleteSceneRequest, DeleteSceneResponse, DeleteWorkspaceRequest, DeleteWorkspaceResponse, EntityPropertyReference, EntitySummary, ErrorDetails, ExecuteQueryRequest, ExecuteQueryResponse, FunctionRequest, FunctionResponse, GetComponentTypeRequest, GetComponentTypeResponse, GetEntityRequest, GetEntityResponse, GetPricingPlanRequest, GetPricingPlanResponse, GetPropertyValueHistoryRequest, GetPropertyValueHistoryResponse, GetPropertyValueRequest, GetPropertyValueResponse, GetSceneRequest, GetSceneResponse, GetWorkspaceRequest, GetWorkspaceResponse, InternalServerException, InterpolationParameters, LambdaFunction, ListComponentTypesFilter, ListComponentTypesRequest, ListComponentTypesResponse, ListEntitiesFilter, ListEntitiesRequest, ListEntitiesResponse, ListScenesRequest, ListScenesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListWorkspacesRequest, ListWorkspacesResponse, OrderBy, ParentEntityUpdateRequest, PricingPlan, PropertyDefinitionRequest, PropertyDefinitionResponse, PropertyFilter, PropertyGroupRequest, PropertyGroupResponse, PropertyLatestValue, PropertyRequest, PropertyResponse, PropertyValue, PropertyValueEntry, PropertyValueHistory, QueryTimeoutException, Relationship, RelationshipValue, ResourceNotFoundException, Row, SceneSummary, ServiceQuotaExceededException, Status, TabularConditions, TagResourceRequest, TagResourceResponse, ThrottlingException, TooManyTagsException, UntagResourceRequest, UntagResourceResponse, UpdateComponentTypeRequest, UpdateComponentTypeResponse, UpdateEntityRequest, UpdateEntityResponse, UpdatePricingPlanRequest, UpdatePricingPlanResponse, UpdateSceneRequest, UpdateSceneResponse, UpdateWorkspaceRequest, UpdateWorkspaceResponse, ValidationException, WorkspaceSummary
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type in the entities in the list.
-
#extends_from ⇒ String
The component type that the component types in the list extend.
-
#external_id ⇒ String
The external-Id property of a component.
-
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component types in the list are abstract.
-
#namespace ⇒ String
The namespace to which the component types in the list belong.
-
#parent_entity_id ⇒ String
The parent of the entities in the list.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type in the entities in the list.
2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2482 class ListEntitiesFilter < Struct.new( :parent_entity_id, :component_type_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParentEntityId < ListEntitiesFilter; end class ComponentTypeId < ListEntitiesFilter; end class ExternalId < ListEntitiesFilter; end class Unknown < ListEntitiesFilter; end end |
#extends_from ⇒ String
The component type that the component types in the list extend.
2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2380 class ListComponentTypesFilter < Struct.new( :extends_from, :namespace, :is_abstract, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExtendsFrom < ListComponentTypesFilter; end class Namespace < ListComponentTypesFilter; end class IsAbstract < ListComponentTypesFilter; end class Unknown < ListComponentTypesFilter; end end |
#external_id ⇒ String
The external-Id property of a component. The external-Id property is the primary key of an external storage system.
2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2482 class ListEntitiesFilter < Struct.new( :parent_entity_id, :component_type_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParentEntityId < ListEntitiesFilter; end class ComponentTypeId < ListEntitiesFilter; end class ExternalId < ListEntitiesFilter; end class Unknown < ListEntitiesFilter; end end |
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component types in the list are abstract.
2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2380 class ListComponentTypesFilter < Struct.new( :extends_from, :namespace, :is_abstract, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExtendsFrom < ListComponentTypesFilter; end class Namespace < ListComponentTypesFilter; end class IsAbstract < ListComponentTypesFilter; end class Unknown < ListComponentTypesFilter; end end |
#namespace ⇒ String
The namespace to which the component types in the list belong.
2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2380 class ListComponentTypesFilter < Struct.new( :extends_from, :namespace, :is_abstract, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExtendsFrom < ListComponentTypesFilter; end class Namespace < ListComponentTypesFilter; end class IsAbstract < ListComponentTypesFilter; end class Unknown < ListComponentTypesFilter; end end |
#parent_entity_id ⇒ String
The parent of the entities in the list.
2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2482 class ListEntitiesFilter < Struct.new( :parent_entity_id, :component_type_id, :external_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParentEntityId < ListEntitiesFilter; end class ComponentTypeId < ListEntitiesFilter; end class ExternalId < ListEntitiesFilter; end class Unknown < ListEntitiesFilter; end end |