Module: Aws::IoTTwinMaker::Types

Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Defined Under Namespace

Classes: AccessDeniedException, BatchPutPropertyError, BatchPutPropertyErrorEntry, BatchPutPropertyValuesRequest, BatchPutPropertyValuesResponse, ComponentRequest, ComponentResponse, ComponentTypeSummary, ComponentUpdateRequest, ConflictException, ConnectorFailureException, ConnectorTimeoutException, CreateComponentTypeRequest, CreateComponentTypeResponse, CreateEntityRequest, CreateEntityResponse, CreateSceneRequest, CreateSceneResponse, CreateWorkspaceRequest, CreateWorkspaceResponse, DataConnector, DataType, DataValue, DeleteComponentTypeRequest, DeleteComponentTypeResponse, DeleteEntityRequest, DeleteEntityResponse, DeleteSceneRequest, DeleteSceneResponse, DeleteWorkspaceRequest, DeleteWorkspaceResponse, EntityPropertyReference, EntitySummary, ErrorDetails, FunctionRequest, FunctionResponse, GetComponentTypeRequest, GetComponentTypeResponse, GetEntityRequest, GetEntityResponse, GetPropertyValueHistoryRequest, GetPropertyValueHistoryResponse, GetPropertyValueRequest, GetPropertyValueResponse, GetSceneRequest, GetSceneResponse, GetWorkspaceRequest, GetWorkspaceResponse, InternalServerException, InterpolationParameters, LambdaFunction, ListComponentTypesFilter, ListComponentTypesRequest, ListComponentTypesResponse, ListEntitiesFilter, ListEntitiesRequest, ListEntitiesResponse, ListScenesRequest, ListScenesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListWorkspacesRequest, ListWorkspacesResponse, ParentEntityUpdateRequest, PropertyDefinitionRequest, PropertyDefinitionResponse, PropertyFilter, PropertyLatestValue, PropertyRequest, PropertyResponse, PropertyValue, PropertyValueEntry, PropertyValueHistory, Relationship, RelationshipValue, ResourceNotFoundException, SceneSummary, ServiceQuotaExceededException, Status, TagResourceRequest, TagResourceResponse, ThrottlingException, TooManyTagsException, UntagResourceRequest, UntagResourceResponse, UpdateComponentTypeRequest, UpdateComponentTypeResponse, UpdateEntityRequest, UpdateEntityResponse, UpdateSceneRequest, UpdateSceneResponse, UpdateWorkspaceRequest, UpdateWorkspaceResponse, ValidationException, WorkspaceSummary

Instance Attribute Summary collapse

Instance Attribute Details

#component_type_idString

The ID of the component type in the entities in the list.

Returns:

  • (String)


2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2187

class ListEntitiesFilter < Struct.new(
  :component_type_id,
  :external_id,
  :parent_entity_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ComponentTypeId < ListEntitiesFilter; end
  class ExternalId < ListEntitiesFilter; end
  class ParentEntityId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end

#extends_fromString

The component type that the component types in the list extend.

Returns:

  • (String)


2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2088

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :is_abstract,
  :namespace,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#external_idString

The external-Id property of a component. The external-Id property is the primary key of an external storage system.

Returns:

  • (String)


2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2187

class ListEntitiesFilter < Struct.new(
  :component_type_id,
  :external_id,
  :parent_entity_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ComponentTypeId < ListEntitiesFilter; end
  class ExternalId < ListEntitiesFilter; end
  class ParentEntityId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end

#is_abstractBoolean

A Boolean value that specifies whether the component types in the list are abstract.

Returns:

  • (Boolean)


2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2088

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :is_abstract,
  :namespace,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#namespaceString

The namespace to which the component types in the list belong.

Returns:

  • (String)


2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2088

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :is_abstract,
  :namespace,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#parent_entity_idString

The parent of the entities in the list.

Returns:

  • (String)


2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2187

class ListEntitiesFilter < Struct.new(
  :component_type_id,
  :external_id,
  :parent_entity_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ComponentTypeId < ListEntitiesFilter; end
  class ExternalId < ListEntitiesFilter; end
  class ParentEntityId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end