Module: Aws::IoTTwinMaker::Types

Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Defined Under Namespace

Classes: AccessDeniedException, BatchPutPropertyError, BatchPutPropertyErrorEntry, BatchPutPropertyValuesRequest, BatchPutPropertyValuesResponse, ComponentRequest, ComponentResponse, ComponentTypeSummary, ComponentUpdateRequest, ConflictException, ConnectorFailureException, ConnectorTimeoutException, CreateComponentTypeRequest, CreateComponentTypeResponse, CreateEntityRequest, CreateEntityResponse, CreateSceneRequest, CreateSceneResponse, CreateWorkspaceRequest, CreateWorkspaceResponse, DataConnector, DataType, DataValue, DeleteComponentTypeRequest, DeleteComponentTypeResponse, DeleteEntityRequest, DeleteEntityResponse, DeleteSceneRequest, DeleteSceneResponse, DeleteWorkspaceRequest, DeleteWorkspaceResponse, EntityPropertyReference, EntitySummary, ErrorDetails, FunctionRequest, FunctionResponse, GetComponentTypeRequest, GetComponentTypeResponse, GetEntityRequest, GetEntityResponse, GetPropertyValueHistoryRequest, GetPropertyValueHistoryResponse, GetPropertyValueRequest, GetPropertyValueResponse, GetSceneRequest, GetSceneResponse, GetWorkspaceRequest, GetWorkspaceResponse, InternalServerException, InterpolationParameters, LambdaFunction, ListComponentTypesFilter, ListComponentTypesRequest, ListComponentTypesResponse, ListEntitiesFilter, ListEntitiesRequest, ListEntitiesResponse, ListScenesRequest, ListScenesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListWorkspacesRequest, ListWorkspacesResponse, ParentEntityUpdateRequest, PropertyDefinitionRequest, PropertyDefinitionResponse, PropertyFilter, PropertyLatestValue, PropertyRequest, PropertyResponse, PropertyValue, PropertyValueEntry, PropertyValueHistory, Relationship, RelationshipValue, ResourceNotFoundException, SceneSummary, ServiceQuotaExceededException, Status, TagResourceRequest, TagResourceResponse, ThrottlingException, TooManyTagsException, UntagResourceRequest, UntagResourceResponse, UpdateComponentTypeRequest, UpdateComponentTypeResponse, UpdateEntityRequest, UpdateEntityResponse, UpdateSceneRequest, UpdateSceneResponse, UpdateWorkspaceRequest, UpdateWorkspaceResponse, ValidationException, WorkspaceSummary

Instance Attribute Summary collapse

Instance Attribute Details

#component_type_idString

The ID of the component type in the entities in the list.

Returns:

  • (String)


2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2151

class ListEntitiesFilter < Struct.new(
  :component_type_id,
  :parent_entity_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ComponentTypeId < ListEntitiesFilter; end
  class ParentEntityId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end

#extends_fromString

The component type that the component types in the list extend.

Returns:

  • (String)


2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2057

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :is_abstract,
  :namespace,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#is_abstractBoolean

A Boolean value that specifies whether the component types in the list are abstract.

Returns:

  • (Boolean)


2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2057

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :is_abstract,
  :namespace,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#namespaceString

The namespace to which the component types in the list belong.

Returns:

  • (String)


2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2057

class ListComponentTypesFilter < Struct.new(
  :extends_from,
  :is_abstract,
  :namespace,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExtendsFrom < ListComponentTypesFilter; end
  class IsAbstract < ListComponentTypesFilter; end
  class Namespace < ListComponentTypesFilter; end
  class Unknown < ListComponentTypesFilter; end
end

#parent_entity_idString

The parent of the entities in the list.

Returns:

  • (String)


2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2151

class ListEntitiesFilter < Struct.new(
  :component_type_id,
  :parent_entity_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ComponentTypeId < ListEntitiesFilter; end
  class ParentEntityId < ListEntitiesFilter; end
  class Unknown < ListEntitiesFilter; end
end