Class: Aws::IoTTwinMaker::Types::ComponentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass ComponentRequest data as a hash:

{
  description: "Description",
  component_type_id: "ComponentTypeId",
  properties: {
    "Name" => {
      definition: {
        data_type: {
          type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
          nested_type: {
            # recursive DataType
          },
          allowed_values: [
            {
              boolean_value: false,
              double_value: 1.0,
              integer_value: 1,
              long_value: 1,
              string_value: "String",
              list_value: {
                # recursive DataValueList
              },
              map_value: {
                "String" => {
                  # recursive DataValue
                },
              },
              relationship_value: {
                target_entity_id: "EntityId",
                target_component_name: "Name",
              },
              expression: "Expression",
            },
          ],
          unit_of_measure: "String",
          relationship: {
            target_component_type_id: "ComponentTypeId",
            relationship_type: "String",
          },
        },
        is_required_in_entity: false,
        is_external_id: false,
        is_stored_externally: false,
        is_time_series: false,
        default_value: {
          boolean_value: false,
          double_value: 1.0,
          integer_value: 1,
          long_value: 1,
          string_value: "String",
          list_value: [
            {
              # recursive DataValue
            },
          ],
          map_value: {
            "String" => {
              # recursive DataValue
            },
          },
          relationship_value: {
            target_entity_id: "EntityId",
            target_component_name: "Name",
          },
          expression: "Expression",
        },
        configuration: {
          "Name" => "Value",
        },
      },
      value: {
        boolean_value: false,
        double_value: 1.0,
        integer_value: 1,
        long_value: 1,
        string_value: "String",
        list_value: [
          {
            # recursive DataValue
          },
        ],
        map_value: {
          "String" => {
            # recursive DataValue
          },
        },
        relationship_value: {
          target_entity_id: "EntityId",
          target_component_name: "Name",
        },
        expression: "Expression",
      },
      update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
    },
  },
  property_groups: {
    "Name" => {
      group_type: "TABULAR", # accepts TABULAR
      property_names: ["Name"],
      update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
    },
  },
}

An object that sets information about a component type create or update request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_type_idString

The ID of the component type.

Returns:

  • (String)


347
348
349
350
351
352
353
354
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 347

class ComponentRequest < Struct.new(
  :description,
  :component_type_id,
  :properties,
  :property_groups)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the component request.

Returns:

  • (String)


347
348
349
350
351
352
353
354
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 347

class ComponentRequest < Struct.new(
  :description,
  :component_type_id,
  :properties,
  :property_groups)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,Types::PropertyRequest>

An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.

Returns:



347
348
349
350
351
352
353
354
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 347

class ComponentRequest < Struct.new(
  :description,
  :component_type_id,
  :properties,
  :property_groups)
  SENSITIVE = []
  include Aws::Structure
end

#property_groupsHash<String,Types::ComponentPropertyGroupRequest>

The property groups.

Returns:



347
348
349
350
351
352
353
354
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 347

class ComponentRequest < Struct.new(
  :description,
  :component_type_id,
  :properties,
  :property_groups)
  SENSITIVE = []
  include Aws::Structure
end