Class: Aws::IoTTwinMaker::Types::ComponentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass ComponentRequest data as a hash:

{
  component_type_id: "ComponentTypeId",
  description: "Description",
  properties: {
    "Name" => {
      definition: {
        configuration: {
          "Name" => "Value",
        },
        data_type: {
          allowed_values: [
            {
              boolean_value: false,
              double_value: 1.0,
              expression: "Expression",
              integer_value: 1,
              list_value: {
                # recursive DataValueList
              },
              long_value: 1,
              map_value: {
                "String" => {
                  # recursive DataValue
                },
              },
              relationship_value: {
                target_component_name: "Name",
                target_entity_id: "EntityId",
              },
              string_value: "String",
            },
          ],
          nested_type: {
            # recursive DataType
          },
          relationship: {
            relationship_type: "String",
            target_component_type_id: "ComponentTypeId",
          },
          type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
          unit_of_measure: "String",
        },
        default_value: {
          boolean_value: false,
          double_value: 1.0,
          expression: "Expression",
          integer_value: 1,
          list_value: [
            {
              # recursive DataValue
            },
          ],
          long_value: 1,
          map_value: {
            "String" => {
              # recursive DataValue
            },
          },
          relationship_value: {
            target_component_name: "Name",
            target_entity_id: "EntityId",
          },
          string_value: "String",
        },
        is_external_id: false,
        is_required_in_entity: false,
        is_stored_externally: false,
        is_time_series: false,
      },
      update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
      value: {
        boolean_value: false,
        double_value: 1.0,
        expression: "Expression",
        integer_value: 1,
        list_value: [
          {
            # recursive DataValue
          },
        ],
        long_value: 1,
        map_value: {
          "String" => {
            # recursive DataValue
          },
        },
        relationship_value: {
          target_component_name: "Name",
          target_entity_id: "EntityId",
        },
        string_value: "String",
      },
    },
  },
}

An object that sets information about a component type create or update request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_type_idString

The ID of the component type.

Returns:

  • (String)


250
251
252
253
254
255
256
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 250

class ComponentRequest < Struct.new(
  :component_type_id,
  :description,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the component request.

Returns:

  • (String)


250
251
252
253
254
255
256
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 250

class ComponentRequest < Struct.new(
  :component_type_id,
  :description,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,Types::PropertyRequest>

An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.

Returns:



250
251
252
253
254
255
256
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 250

class ComponentRequest < Struct.new(
  :component_type_id,
  :description,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end