Class: Aws::IoTTwinMaker::Types::ComponentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::ComponentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that returns information about a component type create or update request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component.
-
#component_type_id ⇒ String
The ID of the component type.
-
#defined_in ⇒ String
The name of the property definition set in the request.
-
#description ⇒ String
The description of the component type.
-
#properties ⇒ Hash<String,Types::PropertyResponse>
An object that maps strings to the properties to set in the component type.
-
#property_groups ⇒ Hash<String,Types::ComponentPropertyGroupResponse>
The property groups.
-
#status ⇒ Types::Status
The status of the component type.
-
#sync_source ⇒ String
The syncSource of the sync job, if this entity was created by a sync job.
Instance Attribute Details
#component_name ⇒ String
The name of the component.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |
#defined_in ⇒ String
The name of the property definition set in the request.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,Types::PropertyResponse>
An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |
#property_groups ⇒ Hash<String,Types::ComponentPropertyGroupResponse>
The property groups.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The status of the component type.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |
#sync_source ⇒ String
The syncSource of the sync job, if this entity was created by a sync job.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 232 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups, :sync_source) SENSITIVE = [] include Aws::Structure end |