Class: Aws::IoTTwinMaker::Types::ComponentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::ComponentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that returns information about a component type create or update request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component.
-
#component_type_id ⇒ String
The ID of the component type.
-
#defined_in ⇒ String
The name of the property definition set in the request.
-
#description ⇒ String
The description of the component type.
-
#properties ⇒ Hash<String,Types::PropertyResponse>
An object that maps strings to the properties to set in the component type.
-
#property_groups ⇒ Hash<String,Types::ComponentPropertyGroupResponse>
The property groups.
-
#status ⇒ Types::Status
The status of the component type.
Instance Attribute Details
#component_name ⇒ String
The name of the component.
389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 389 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 389 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#defined_in ⇒ String
The name of the property definition set in the request.
389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 389 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 389 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,Types::PropertyResponse>
An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.
389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 389 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#property_groups ⇒ Hash<String,Types::ComponentPropertyGroupResponse>
The property groups.
389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 389 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The status of the component type.
389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 389 class ComponentResponse < Struct.new( :component_name, :description, :component_type_id, :status, :defined_in, :properties, :property_groups) SENSITIVE = [] include Aws::Structure end |