Class: Aws::IoTTwinMaker::Types::ComponentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

An object that returns information about a component type create or update request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_nameString

The name of the component.

Returns:

  • (String)


287
288
289
290
291
292
293
294
295
296
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 287

class ComponentResponse < Struct.new(
  :component_name,
  :component_type_id,
  :defined_in,
  :description,
  :properties,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#component_type_idString

The ID of the component type.

Returns:

  • (String)


287
288
289
290
291
292
293
294
295
296
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 287

class ComponentResponse < Struct.new(
  :component_name,
  :component_type_id,
  :defined_in,
  :description,
  :properties,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#defined_inString

The name of the property definition set in the request.

Returns:

  • (String)


287
288
289
290
291
292
293
294
295
296
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 287

class ComponentResponse < Struct.new(
  :component_name,
  :component_type_id,
  :defined_in,
  :description,
  :properties,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the component type.

Returns:

  • (String)


287
288
289
290
291
292
293
294
295
296
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 287

class ComponentResponse < Struct.new(
  :component_name,
  :component_type_id,
  :defined_in,
  :description,
  :properties,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,Types::PropertyResponse>

An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.

Returns:



287
288
289
290
291
292
293
294
295
296
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 287

class ComponentResponse < Struct.new(
  :component_name,
  :component_type_id,
  :defined_in,
  :description,
  :properties,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::Status

The status of the component type.

Returns:



287
288
289
290
291
292
293
294
295
296
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 287

class ComponentResponse < Struct.new(
  :component_name,
  :component_type_id,
  :defined_in,
  :description,
  :properties,
  :status)
  SENSITIVE = []
  include Aws::Structure
end