Class: Aws::IoTTwinMaker::Types::ComponentUpdateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass ComponentUpdateRequest data as a hash:

{
  component_type_id: "ComponentTypeId",
  description: "Description",
  property_updates: {
    "Name" => {
      definition: {
        configuration: {
          "Name" => "Value",
        },
        data_type: {
          allowed_values: [
            {
              boolean_value: false,
              double_value: 1.0,
              expression: "Expression",
              integer_value: 1,
              list_value: {
                # recursive DataValueList
              },
              long_value: 1,
              map_value: {
                "String" => {
                  # recursive DataValue
                },
              },
              relationship_value: {
                target_component_name: "Name",
                target_entity_id: "EntityId",
              },
              string_value: "String",
            },
          ],
          nested_type: {
            # recursive DataType
          },
          relationship: {
            relationship_type: "String",
            target_component_type_id: "ComponentTypeId",
          },
          type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
          unit_of_measure: "String",
        },
        default_value: {
          boolean_value: false,
          double_value: 1.0,
          expression: "Expression",
          integer_value: 1,
          list_value: [
            {
              # recursive DataValue
            },
          ],
          long_value: 1,
          map_value: {
            "String" => {
              # recursive DataValue
            },
          },
          relationship_value: {
            target_component_name: "Name",
            target_entity_id: "EntityId",
          },
          string_value: "String",
        },
        is_external_id: false,
        is_required_in_entity: false,
        is_stored_externally: false,
        is_time_series: false,
      },
      update_type: "UPDATE", # accepts UPDATE, DELETE
      value: {
        boolean_value: false,
        double_value: 1.0,
        expression: "Expression",
        integer_value: 1,
        list_value: [
          {
            # recursive DataValue
          },
        ],
        long_value: 1,
        map_value: {
          "String" => {
            # recursive DataValue
          },
        },
        relationship_value: {
          target_component_name: "Name",
          target_entity_id: "EntityId",
        },
        string_value: "String",
      },
    },
  },
  update_type: "CREATE", # accepts CREATE, UPDATE, DELETE
}

The component update request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_type_idString

The ID of the component type.

Returns:

  • (String)


454
455
456
457
458
459
460
461
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 454

class ComponentUpdateRequest < Struct.new(
  :component_type_id,
  :description,
  :property_updates,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the component type.

Returns:

  • (String)


454
455
456
457
458
459
460
461
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 454

class ComponentUpdateRequest < Struct.new(
  :component_type_id,
  :description,
  :property_updates,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#property_updatesHash<String,Types::PropertyRequest>

An object that maps strings to the properties to set in the component type update. Each string in the mapping must be unique to this object.

Returns:



454
455
456
457
458
459
460
461
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 454

class ComponentUpdateRequest < Struct.new(
  :component_type_id,
  :description,
  :property_updates,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#update_typeString

The update type of the component update request.

Returns:

  • (String)


454
455
456
457
458
459
460
461
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 454

class ComponentUpdateRequest < Struct.new(
  :component_type_id,
  :description,
  :property_updates,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end