Class: Aws::IoTTwinMaker::Types::CreateEntityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#componentsHash<String,Types::ComponentRequest>

An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.

Returns:



463
464
465
466
467
468
469
470
471
472
473
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 463

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entity.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
472
473
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 463

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
472
473
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 463

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

The name of the entity.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
472
473
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 463

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#parent_entity_idString

The ID of the entity’s parent entity.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
472
473
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 463

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Metadata that you can use to manage the entity.

Returns:

  • (Hash<String,String>)


463
464
465
466
467
468
469
470
471
472
473
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 463

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace that contains the entity.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
472
473
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 463

class CreateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :components,
  :parent_entity_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end