Class: Aws::IoTTwinMaker::Types::CreateEntityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::CreateEntityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass CreateEntityRequest data as a hash:
{
components: {
"Name" => {
component_type_id: "ComponentTypeId",
description: "Description",
properties: {
"Name" => {
definition: {
configuration: {
"Name" => "Value",
},
data_type: {
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: {
# recursive DataValueList
},
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
],
nested_type: {
# recursive DataType
},
relationship: {
relationship_type: "String",
target_component_type_id: "ComponentTypeId",
},
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
unit_of_measure: "String",
},
default_value: {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
is_external_id: false,
is_required_in_entity: false,
is_stored_externally: false,
is_time_series: false,
},
update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
value: {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
},
},
},
},
description: "Description",
entity_id: "EntityId",
entity_name: "EntityName", # required
parent_entity_id: "ParentEntityId",
tags: {
"TagKey" => "TagValue",
},
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#components ⇒ Hash<String,Types::ComponentRequest>
An object that maps strings to the components in the entity.
-
#description ⇒ String
The description of the entity.
-
#entity_id ⇒ String
The ID of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#parent_entity_id ⇒ String
The ID of the entity's parent entity.
-
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the entity.
-
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
Instance Attribute Details
#components ⇒ Hash<String,Types::ComponentRequest>
An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 798 class CreateEntityRequest < Struct.new( :components, :description, :entity_id, :entity_name, :parent_entity_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the entity.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 798 class CreateEntityRequest < Struct.new( :components, :description, :entity_id, :entity_name, :parent_entity_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 798 class CreateEntityRequest < Struct.new( :components, :description, :entity_id, :entity_name, :parent_entity_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 798 class CreateEntityRequest < Struct.new( :components, :description, :entity_id, :entity_name, :parent_entity_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#parent_entity_id ⇒ String
The ID of the entity's parent entity.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 798 class CreateEntityRequest < Struct.new( :components, :description, :entity_id, :entity_name, :parent_entity_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the entity.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 798 class CreateEntityRequest < Struct.new( :components, :description, :entity_id, :entity_name, :parent_entity_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 798 class CreateEntityRequest < Struct.new( :components, :description, :entity_id, :entity_name, :parent_entity_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |