Method: Aws::IoTTwinMaker::Types::CreateEntityRequest#components
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
#components ⇒ Hash<String,Types::ComponentRequest>
An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.
673 674 675 676 677 678 679 680 681 682 683 684 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 673 class CreateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :components, :composite_components, :parent_entity_id, :tags) SENSITIVE = [] include Aws::Structure end |