Class: Aws::IoTTwinMaker::Types::CreateSceneRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::CreateSceneRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass CreateSceneRequest data as a hash:
{
capabilities: ["SceneCapability"],
content_location: "S3Url", # required
description: "Description",
scene_id: "Id", # required
tags: {
"TagKey" => "TagValue",
},
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capabilities ⇒ Array<String>
A list of capabilities that the scene uses to render itself.
-
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
-
#description ⇒ String
The description for this scene.
-
#scene_id ⇒ String
The ID of the scene.
-
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the scene.
-
#workspace_id ⇒ String
The ID of the workspace that contains the scene.
Instance Attribute Details
#capabilities ⇒ Array<String>
A list of capabilities that the scene uses to render itself.
874 875 876 877 878 879 880 881 882 883 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874 class CreateSceneRequest < Struct.new( :capabilities, :content_location, :description, :scene_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
874 875 876 877 878 879 880 881 882 883 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874 class CreateSceneRequest < Struct.new( :capabilities, :content_location, :description, :scene_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for this scene.
874 875 876 877 878 879 880 881 882 883 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874 class CreateSceneRequest < Struct.new( :capabilities, :content_location, :description, :scene_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#scene_id ⇒ String
The ID of the scene.
874 875 876 877 878 879 880 881 882 883 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874 class CreateSceneRequest < Struct.new( :capabilities, :content_location, :description, :scene_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata that you can use to manage the scene.
874 875 876 877 878 879 880 881 882 883 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874 class CreateSceneRequest < Struct.new( :capabilities, :content_location, :description, :scene_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the scene.
874 875 876 877 878 879 880 881 882 883 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 874 class CreateSceneRequest < Struct.new( :capabilities, :content_location, :description, :scene_id, :tags, :workspace_id) SENSITIVE = [] include Aws::Structure end |