Class: Aws::IoTTwinMaker::Types::CreateSyncJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sync_roleString

The SyncJob IAM role. This IAM role is used by the sync job to read from the syncSource, and create, update or delete the corresponding resources.

Returns:

  • (String)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571

class CreateSyncJobRequest < Struct.new(
  :workspace_id,
  :sync_source,
  :sync_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#sync_sourceString

The sync source.

<note markdown=“1”> Currently the only supported syncSoucre is `SITEWISE `.

</note>

Returns:

  • (String)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571

class CreateSyncJobRequest < Struct.new(
  :workspace_id,
  :sync_source,
  :sync_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The SyncJob tags.

Returns:

  • (Hash<String,String>)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571

class CreateSyncJobRequest < Struct.new(
  :workspace_id,
  :sync_source,
  :sync_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The workspace Id.

Returns:

  • (String)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 571

class CreateSyncJobRequest < Struct.new(
  :workspace_id,
  :sync_source,
  :sync_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end