Class: Aws::IoTTwinMaker::Types::CreateWorkspaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass CreateWorkspaceRequest data as a hash:

{
  description: "Description",
  role: "RoleArn", # required
  s3_location: "S3Location", # required
  tags: {
    "TagKey" => "TagValue",
  },
  workspace_id: "Id", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the workspace.

Returns:

  • (String)


934
935
936
937
938
939
940
941
942
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934

class CreateWorkspaceRequest < Struct.new(
  :description,
  :role,
  :s3_location,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The ARN of the execution role associated with the workspace.

Returns:

  • (String)


934
935
936
937
938
939
940
941
942
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934

class CreateWorkspaceRequest < Struct.new(
  :description,
  :role,
  :s3_location,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationString

The ARN of the S3 bucket where resources associated with the workspace are stored.

Returns:

  • (String)


934
935
936
937
938
939
940
941
942
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934

class CreateWorkspaceRequest < Struct.new(
  :description,
  :role,
  :s3_location,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Metadata that you can use to manage the workspace

Returns:

  • (Hash<String,String>)


934
935
936
937
938
939
940
941
942
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934

class CreateWorkspaceRequest < Struct.new(
  :description,
  :role,
  :s3_location,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace.

Returns:

  • (String)


934
935
936
937
938
939
940
941
942
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 934

class CreateWorkspaceRequest < Struct.new(
  :description,
  :role,
  :s3_location,
  :tags,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end