Class: Aws::IoTTwinMaker::Types::DataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::DataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass DataType data as a hash:
{
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: {
# recursive DataValueList
},
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
],
nested_type: {
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: {
# recursive DataValueList
},
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
],
nested_type: {
# recursive DataType
},
relationship: {
relationship_type: "String",
target_component_type_id: "ComponentTypeId",
},
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
unit_of_measure: "String",
},
relationship: {
relationship_type: "String",
target_component_type_id: "ComponentTypeId",
},
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
unit_of_measure: "String",
}
An object that specifies the data type of a property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<Types::DataValue>
The allowed values for this data type.
-
#nested_type ⇒ Types::DataType
The nested type in the data type.
-
#relationship ⇒ Types::Relationship
A relationship that associates a component with another component.
-
#type ⇒ String
The underlying type of the data type.
-
#unit_of_measure ⇒ String
The unit of measure used in this data type.
Instance Attribute Details
#allowed_values ⇒ Array<Types::DataValue>
The allowed values for this data type.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1076 class DataType < Struct.new( :allowed_values, :nested_type, :relationship, :type, :unit_of_measure) SENSITIVE = [] include Aws::Structure end |
#nested_type ⇒ Types::DataType
The nested type in the data type.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1076 class DataType < Struct.new( :allowed_values, :nested_type, :relationship, :type, :unit_of_measure) SENSITIVE = [] include Aws::Structure end |
#relationship ⇒ Types::Relationship
A relationship that associates a component with another component.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1076 class DataType < Struct.new( :allowed_values, :nested_type, :relationship, :type, :unit_of_measure) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The underlying type of the data type.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1076 class DataType < Struct.new( :allowed_values, :nested_type, :relationship, :type, :unit_of_measure) SENSITIVE = [] include Aws::Structure end |
#unit_of_measure ⇒ String
The unit of measure used in this data type.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1076 class DataType < Struct.new( :allowed_values, :nested_type, :relationship, :type, :unit_of_measure) SENSITIVE = [] include Aws::Structure end |