Class: Aws::IoTTwinMaker::Types::DataValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass DataValue data as a hash:

{
  boolean_value: false,
  double_value: 1.0,
  expression: "Expression",
  integer_value: 1,
  list_value: [
    {
      boolean_value: false,
      double_value: 1.0,
      expression: "Expression",
      integer_value: 1,
      list_value: {
        # recursive DataValueList
      },
      long_value: 1,
      map_value: {
        "String" => {
          # recursive DataValue
        },
      },
      relationship_value: {
        target_component_name: "Name",
        target_entity_id: "EntityId",
      },
      string_value: "String",
    },
  ],
  long_value: 1,
  map_value: {
    "String" => {
      boolean_value: false,
      double_value: 1.0,
      expression: "Expression",
      integer_value: 1,
      list_value: [
        {
          # recursive DataValue
        },
      ],
      long_value: 1,
      map_value: {
        # recursive DataValueMap
      },
      relationship_value: {
        target_component_name: "Name",
        target_entity_id: "EntityId",
      },
      string_value: "String",
    },
  },
  relationship_value: {
    target_component_name: "Name",
    target_entity_id: "EntityId",
  },
  string_value: "String",
}

An object that specifies a value for a property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#boolean_valueBoolean

A Boolean value.

Returns:

  • (Boolean)


1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#double_valueFloat

A double value.

Returns:

  • (Float)


1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#expressionString

An expression that produces the value.

Returns:

  • (String)


1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#integer_valueInteger

An integer value.

Returns:

  • (Integer)


1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#list_valueArray<Types::DataValue>

A list of multiple values.

Returns:



1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#long_valueInteger

A long value.

Returns:

  • (Integer)


1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#map_valueHash<String,Types::DataValue>

An object that maps strings to multiple `DataValue` objects.

Returns:



1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#relationship_valueTypes::RelationshipValue

A value that relates a component to another component.



1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end

#string_valueString

A string value.

Returns:

  • (String)


1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1184

class DataValue < Struct.new(
  :boolean_value,
  :double_value,
  :expression,
  :integer_value,
  :list_value,
  :long_value,
  :map_value,
  :relationship_value,
  :string_value)
  SENSITIVE = []
  include Aws::Structure
end