Class: Aws::IoTTwinMaker::Types::DataValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::DataValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass DataValue data as a hash:
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: {
# recursive DataValueList
},
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
],
long_value: 1,
map_value: {
"String" => {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
# recursive DataValueMap
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
}
An object that specifies a value for a property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#boolean_value ⇒ Boolean
A Boolean value.
-
#double_value ⇒ Float
A double value.
-
#expression ⇒ String
An expression that produces the value.
-
#integer_value ⇒ Integer
An integer value.
-
#list_value ⇒ Array<Types::DataValue>
A list of multiple values.
-
#long_value ⇒ Integer
A long value.
-
#map_value ⇒ Hash<String,Types::DataValue>
An object that maps strings to multiple `DataValue` objects.
-
#relationship_value ⇒ Types::RelationshipValue
A value that relates a component to another component.
-
#string_value ⇒ String
A string value.
Instance Attribute Details
#boolean_value ⇒ Boolean
A Boolean value.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#double_value ⇒ Float
A double value.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#expression ⇒ String
An expression that produces the value.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#integer_value ⇒ Integer
An integer value.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#list_value ⇒ Array<Types::DataValue>
A list of multiple values.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#long_value ⇒ Integer
A long value.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#map_value ⇒ Hash<String,Types::DataValue>
An object that maps strings to multiple `DataValue` objects.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#relationship_value ⇒ Types::RelationshipValue
A value that relates a component to another component.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |
#string_value ⇒ String
A string value.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1183 class DataValue < Struct.new( :boolean_value, :double_value, :expression, :integer_value, :list_value, :long_value, :map_value, :relationship_value, :string_value) SENSITIVE = [] include Aws::Structure end |