Class: Aws::IoTTwinMaker::Types::DeleteEntityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass DeleteEntityRequest data as a hash:

{
  entity_id: "EntityId", # required
  is_recursive: false,
  workspace_id: "Id", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entity_idString

The ID of the entity to delete.

Returns:

  • (String)


1252
1253
1254
1255
1256
1257
1258
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1252

class DeleteEntityRequest < Struct.new(
  :entity_id,
  :is_recursive,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#is_recursiveBoolean

A Boolean value that specifies whether the operation deletes child entities.

Returns:

  • (Boolean)


1252
1253
1254
1255
1256
1257
1258
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1252

class DeleteEntityRequest < Struct.new(
  :entity_id,
  :is_recursive,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace that contains the entity to delete.

Returns:

  • (String)


1252
1253
1254
1255
1256
1257
1258
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1252

class DeleteEntityRequest < Struct.new(
  :entity_id,
  :is_recursive,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end