Class: Aws::IoTTwinMaker::Types::EntitySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

An object that contains information about an entity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the entity.

Returns:

  • (String)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the entity was created.

Returns:

  • (Time)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entity.

Returns:

  • (String)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity.

Returns:

  • (String)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

The name of the entity.

Returns:

  • (String)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#has_child_entitiesBoolean

A Boolean value that specifies whether the entity has child entities or not.

Returns:

  • (Boolean)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#parent_entity_idString

The ID of the parent entity.

Returns:

  • (String)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::Status

The current status of the entity.

Returns:



1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The last date and time when the entity was updated.

Returns:

  • (Time)


1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1526

class EntitySummary < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :parent_entity_id,
  :status,
  :description,
  :has_child_entities,
  :creation_date_time,
  :update_date_time)
  SENSITIVE = []
  include Aws::Structure
end