Class: Aws::IoTTwinMaker::Types::ExecuteQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::ExecuteQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#query_statement ⇒ String
The query statement.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return at one time. The default is 25.
Valid Range: Minimum value of 1. Maximum value of 250.
979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 979 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The string that specifies the next page of results.
979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 979 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#query_statement ⇒ String
The query statement.
979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 979 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 979 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |