Class: Aws::IoTTwinMaker::Types::ExecuteQueryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass ExecuteQueryRequest data as a hash:

{
  workspace_id: "Id", # required
  query_statement: "QueryStatement", # required
  max_results: 1,
  next_token: "NextToken",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return at one time. The default is 25.

Valid Range: Minimum value of 1. Maximum value of 250.

Returns:

  • (Integer)


1586
1587
1588
1589
1590
1591
1592
1593
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The string that specifies the next page of results.

Returns:

  • (String)


1586
1587
1588
1589
1590
1591
1592
1593
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#query_statementString

The query statement.

Returns:

  • (String)


1586
1587
1588
1589
1590
1591
1592
1593
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace.

Returns:

  • (String)


1586
1587
1588
1589
1590
1591
1592
1593
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586

class ExecuteQueryRequest < Struct.new(
  :workspace_id,
  :query_statement,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end