Class: Aws::IoTTwinMaker::Types::ExecuteQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::ExecuteQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass ExecuteQueryRequest data as a hash:
{
workspace_id: "Id", # required
query_statement: "QueryStatement", # required
max_results: 1,
next_token: "NextToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#query_statement ⇒ String
The query statement.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return at one time. The default is 25.
Valid Range: Minimum value of 1. Maximum value of 250.
1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The string that specifies the next page of results.
1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#query_statement ⇒ String
The query statement.
1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1586 class ExecuteQueryRequest < Struct.new( :workspace_id, :query_statement, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |