Class: Aws::IoTTwinMaker::Types::GetComponentTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the component type.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#component_type_idString

The ID of the component type.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#component_type_nameString

The component type name.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the component type was created.

Returns:

  • (Time)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the component type.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#extends_fromArray<String>

The name of the parent component type that this component type extends.

Returns:

  • (Array<String>)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#functionsHash<String,Types::FunctionResponse>

An object that maps strings to the functions in the component type. Each string in the mapping must be unique to this object.

Returns:



1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#is_abstractBoolean

A Boolean value that specifies whether the component type is abstract.

Returns:

  • (Boolean)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#is_schema_initializedBoolean

A Boolean value that specifies whether the component type has a schema initializer and that the schema initializer has run.

Returns:

  • (Boolean)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#is_singletonBoolean

A Boolean value that specifies whether an entity can have more than one component of this type.

Returns:

  • (Boolean)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#property_definitionsHash<String,Types::PropertyDefinitionResponse>

An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.

Returns:



1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#property_groupsHash<String,Types::PropertyGroupResponse>

The maximum number of results to return at one time. The default is 25.

Valid Range: Minimum value of 1. Maximum value of 250.

Returns:



1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::Status

The current status of the component type.

Returns:



1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#sync_sourceString

The syncSource of the sync job, if this entity was created by a sync job.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The date and time when the component was last updated.

Returns:

  • (Time)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace that contains the component type.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1147

class GetComponentTypeResponse < Struct.new(
  :workspace_id,
  :is_singleton,
  :component_type_id,
  :description,
  :property_definitions,
  :extends_from,
  :functions,
  :creation_date_time,
  :update_date_time,
  :arn,
  :is_abstract,
  :is_schema_initialized,
  :status,
  :property_groups,
  :sync_source,
  :component_type_name)
  SENSITIVE = []
  include Aws::Structure
end