Class: Aws::IoTTwinMaker::Types::GetComponentTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the component type.

Returns:

  • (String)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#component_type_idString

The ID of the component type.

Returns:

  • (String)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the component type was created.

Returns:

  • (Time)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the component type.

Returns:

  • (String)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#extends_fromArray<String>

The name of the parent component type that this component type extends.

Returns:

  • (Array<String>)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#functionsHash<String,Types::FunctionResponse>

An object that maps strings to the functions in the component type. Each string in the mapping must be unique to this object.

Returns:



1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#is_abstractBoolean

A Boolean value that specifies whether the component type is abstract.

Returns:

  • (Boolean)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#is_schema_initializedBoolean

A Boolean value that specifies whether the component type has a schema initializer and that the schema initializer has run.

Returns:

  • (Boolean)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#is_singletonBoolean

A Boolean value that specifies whether an entity can have more than one component of this type.

Returns:

  • (Boolean)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#property_definitionsHash<String,Types::PropertyDefinitionResponse>

An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.

Returns:



1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::Status

The current status of the component type.

Returns:



1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The date and time when the component was last updated.

Returns:

  • (Time)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace that contains the component type.

Returns:

  • (String)


1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570

class GetComponentTypeResponse < Struct.new(
  :arn,
  :component_type_id,
  :creation_date_time,
  :description,
  :extends_from,
  :functions,
  :is_abstract,
  :is_schema_initialized,
  :is_singleton,
  :property_definitions,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end