Class: Aws::IoTTwinMaker::Types::GetComponentTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetComponentTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the component type.
-
#component_type_id ⇒ String
The ID of the component type.
-
#creation_date_time ⇒ Time
The date and time when the component type was created.
-
#description ⇒ String
The description of the component type.
-
#extends_from ⇒ Array<String>
The name of the parent component type that this component type extends.
-
#functions ⇒ Hash<String,Types::FunctionResponse>
An object that maps strings to the functions in the component type.
-
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component type is abstract.
-
#is_schema_initialized ⇒ Boolean
A Boolean value that specifies whether the component type has a schema initializer and that the schema initializer has run.
-
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
-
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionResponse>
An object that maps strings to the property definitions in the component type.
-
#status ⇒ Types::Status
The current status of the component type.
-
#update_date_time ⇒ Time
The date and time when the component was last updated.
-
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
Instance Attribute Details
#arn ⇒ String
The ARN of the component type.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the component type was created.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#extends_from ⇒ Array<String>
The name of the parent component type that this component type extends.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#functions ⇒ Hash<String,Types::FunctionResponse>
An object that maps strings to the functions in the component type. Each string in the mapping must be unique to this object.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#is_abstract ⇒ Boolean
A Boolean value that specifies whether the component type is abstract.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#is_schema_initialized ⇒ Boolean
A Boolean value that specifies whether the component type has a schema initializer and that the schema initializer has run.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionResponse>
An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The current status of the component type.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the component was last updated.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1570 class GetComponentTypeResponse < Struct.new( :arn, :component_type_id, :creation_date_time, :description, :extends_from, :functions, :is_abstract, :is_schema_initialized, :is_singleton, :property_definitions, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |