Method: Aws::IoTTwinMaker::Types::GetComponentTypeResponse#is_schema_initialized
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
#is_schema_initialized ⇒ Boolean
A Boolean value that specifies whether the component type has a schema initializer and that the schema initializer has run.
1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1536 class GetComponentTypeResponse < Struct.new( :workspace_id, :is_singleton, :component_type_id, :description, :property_definitions, :extends_from, :functions, :creation_date_time, :update_date_time, :arn, :is_abstract, :is_schema_initialized, :status, :property_groups, :sync_source, :component_type_name, :composite_component_types) SENSITIVE = [] include Aws::Structure end |