Class: Aws::IoTTwinMaker::Types::GetEntityResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the entity.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#componentsHash<String,Types::ComponentResponse>

An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.

Returns:



1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the entity was created.

Returns:

  • (Time)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entity.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

The name of the entity.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#has_child_entitiesBoolean

A Boolean value that specifies whether the entity has associated child entities.

Returns:

  • (Boolean)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#parent_entity_idString

The ID of the parent entity for this entity.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::Status

The current status of the entity.

Returns:



1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#sync_sourceString

The syncSource of the sync job, if this entity was created by a sync job.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The date and time when the entity was last updated.

Returns:

  • (Time)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234

class GetEntityResponse < Struct.new(
  :entity_id,
  :entity_name,
  :arn,
  :status,
  :workspace_id,
  :description,
  :components,
  :parent_entity_id,
  :has_child_entities,
  :creation_date_time,
  :update_date_time,
  :sync_source)
  SENSITIVE = []
  include Aws::Structure
end