Class: Aws::IoTTwinMaker::Types::GetEntityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetEntityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the entity.
-
#components ⇒ Hash<String,Types::ComponentResponse>
An object that maps strings to the components in the entity.
-
#creation_date_time ⇒ Time
The date and time when the entity was created.
-
#description ⇒ String
The description of the entity.
-
#entity_id ⇒ String
The ID of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#has_child_entities ⇒ Boolean
A Boolean value that specifies whether the entity has associated child entities.
-
#parent_entity_id ⇒ String
The ID of the parent entity for this entity.
-
#status ⇒ Types::Status
The current status of the entity.
-
#sync_source ⇒ String
The syncSource of the sync job, if this entity was created by a sync job.
-
#update_date_time ⇒ Time
The date and time when the entity was last updated.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#arn ⇒ String
The ARN of the entity.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#components ⇒ Hash<String,Types::ComponentResponse>
An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the entity was created.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the entity.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#has_child_entities ⇒ Boolean
A Boolean value that specifies whether the entity has associated child entities.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#parent_entity_id ⇒ String
The ID of the parent entity for this entity.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The current status of the entity.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#sync_source ⇒ String
The syncSource of the sync job, if this entity was created by a sync job.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the entity was last updated.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1234 class GetEntityResponse < Struct.new( :entity_id, :entity_name, :arn, :status, :workspace_id, :description, :components, :parent_entity_id, :has_child_entities, :creation_date_time, :update_date_time, :sync_source) SENSITIVE = [] include Aws::Structure end |