Class: Aws::IoTTwinMaker::Types::GetEntityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetEntityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the entity.
-
#components ⇒ Hash<String,Types::ComponentResponse>
An object that maps strings to the components in the entity.
-
#creation_date_time ⇒ Time
The date and time when the entity was created.
-
#description ⇒ String
The description of the entity.
-
#entity_id ⇒ String
The ID of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#has_child_entities ⇒ Boolean
A Boolean value that specifies whether the entity has associated child entities.
-
#parent_entity_id ⇒ String
The ID of the parent entity for this entity.
-
#status ⇒ Types::Status
The current status of the entity.
-
#update_date_time ⇒ Time
The date and time when the entity was last updated.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#arn ⇒ String
The ARN of the entity.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#components ⇒ Hash<String,Types::ComponentResponse>
An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the entity was created.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the entity.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#has_child_entities ⇒ Boolean
A Boolean value that specifies whether the entity has associated child entities.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#parent_entity_id ⇒ String
The ID of the parent entity for this entity.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::Status
The current status of the entity.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the entity was last updated.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1657 class GetEntityResponse < Struct.new( :arn, :components, :creation_date_time, :description, :entity_id, :entity_name, :has_child_entities, :parent_entity_id, :status, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |