Class: Aws::IoTTwinMaker::Types::GetEntityResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the entity.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#componentsHash<String,Types::ComponentResponse>

An object that maps strings to the components in the entity. Each string in the mapping must be unique to this object.

Returns:



1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the entity was created.

Returns:

  • (Time)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entity.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

The name of the entity.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#has_child_entitiesBoolean

A Boolean value that specifies whether the entity has associated child entities.

Returns:

  • (Boolean)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#parent_entity_idString

The ID of the parent entity for this entity.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::Status

The current status of the entity.

Returns:



1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The date and time when the entity was last updated.

Returns:

  • (Time)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1656

class GetEntityResponse < Struct.new(
  :arn,
  :components,
  :creation_date_time,
  :description,
  :entity_id,
  :entity_name,
  :has_child_entities,
  :parent_entity_id,
  :status,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end