Class: Aws::IoTTwinMaker::Types::GetPropertyValueHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_nameString

The name of the component.

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#component_type_idString

The ID of the component type.

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_timeTime

The date and time of the latest property value to return.

Returns:

  • (Time)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeString

The ISO8601 DateTime of the latest property value to return.

For more information about the ISO8601 DateTime format, see the data type [PropertyValue].

[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_PropertyValue.html

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity.

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#interpolationTypes::InterpolationParameters

An object that specifies the interpolation type and the interval over which to interpolate data.



1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return at one time. The default is 25.

Valid Range: Minimum value of 1. Maximum value of 250.

Returns:

  • (Integer)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The string that specifies the next page of results.

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#order_by_timeString

The time direction to use in the result order.

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#property_filtersArray<Types::PropertyFilter>

A list of objects that filter the property value history request.

Returns:



1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#selected_propertiesArray<String>

A list of properties whose value histories the request retrieves.

Returns:

  • (Array<String>)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_timeTime

The date and time of the earliest property value to return.

Returns:

  • (Time)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeString

The ISO8601 DateTime of the earliest property value to return.

For more information about the ISO8601 DateTime format, see the data type [PropertyValue].

[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_PropertyValue.html

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace.

Returns:

  • (String)


1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344

class GetPropertyValueHistoryRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :component_name,
  :component_type_id,
  :selected_properties,
  :property_filters,
  :start_date_time,
  :end_date_time,
  :interpolation,
  :next_token,
  :max_results,
  :order_by_time,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end