Class: Aws::IoTTwinMaker::Types::GetPropertyValueHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component.
-
#component_type_id ⇒ String
The ID of the component type.
-
#end_date_time ⇒ Time
The date and time of the latest property value to return.
-
#end_time ⇒ String
The ISO8601 DateTime of the latest property value to return.
-
#entity_id ⇒ String
The ID of the entity.
-
#interpolation ⇒ Types::InterpolationParameters
An object that specifies the interpolation type and the interval over which to interpolate data.
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#order_by_time ⇒ String
The time direction to use in the result order.
-
#property_filters ⇒ Array<Types::PropertyFilter>
A list of objects that filter the property value history request.
-
#selected_properties ⇒ Array<String>
A list of properties whose value histories the request retrieves.
-
#start_date_time ⇒ Time
The date and time of the earliest property value to return.
-
#start_time ⇒ String
The ISO8601 DateTime of the earliest property value to return.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#component_name ⇒ String
The name of the component.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_date_time ⇒ Time
The date and time of the latest property value to return.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ String
The ISO8601 DateTime of the latest property value to return.
For more information about the ISO8601 DateTime format, see the data type [PropertyValue].
[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_PropertyValue.html
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#interpolation ⇒ Types::InterpolationParameters
An object that specifies the interpolation type and the interval over which to interpolate data.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return at one time. The default is 25.
Valid Range: Minimum value of 1. Maximum value of 250.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The string that specifies the next page of results.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#order_by_time ⇒ String
The time direction to use in the result order.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#property_filters ⇒ Array<Types::PropertyFilter>
A list of objects that filter the property value history request.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#selected_properties ⇒ Array<String>
A list of properties whose value histories the request retrieves.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_date_time ⇒ Time
The date and time of the earliest property value to return.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The ISO8601 DateTime of the earliest property value to return.
For more information about the ISO8601 DateTime format, see the data type [PropertyValue].
[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_PropertyValue.html
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1344 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |