Class: Aws::IoTTwinMaker::Types::GetPropertyValueHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
When making an API call, you may pass GetPropertyValueHistoryRequest data as a hash:
{
workspace_id: "Id", # required
entity_id: "EntityId",
component_name: "Name",
component_type_id: "ComponentTypeId",
selected_properties: ["String"], # required
property_filters: [
{
property_name: "String",
operator: "String",
value: {
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: [
{
# recursive DataValue
},
],
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
},
],
start_date_time: Time.now,
end_date_time: Time.now,
interpolation: {
interpolation_type: "LINEAR", # accepts LINEAR
interval_in_seconds: 1,
},
next_token: "NextToken",
max_results: 1,
order_by_time: "ASCENDING", # accepts ASCENDING, DESCENDING
start_time: "Time",
end_time: "Time",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component.
-
#component_type_id ⇒ String
The ID of the component type.
-
#end_date_time ⇒ Time
The date and time of the latest property value to return.
-
#end_time ⇒ String
The ISO8601 DateTime of the latest property value to return.
-
#entity_id ⇒ String
The ID of the entity.
-
#interpolation ⇒ Types::InterpolationParameters
An object that specifies the interpolation type and the interval over which to interpolate data.
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#order_by_time ⇒ String
The time direction to use in the result order.
-
#property_filters ⇒ Array<Types::PropertyFilter>
A list of objects that filter the property value history request.
-
#selected_properties ⇒ Array<String>
A list of properties whose value histories the request retrieves.
-
#start_date_time ⇒ Time
The date and time of the earliest property value to return.
-
#start_time ⇒ String
The ISO8601 DateTime of the earliest property value to return.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#component_name ⇒ String
The name of the component.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_date_time ⇒ Time
The date and time of the latest property value to return.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ String
The ISO8601 DateTime of the latest property value to return.
For more information about the ISO8601 DateTime format, see the data type [PropertyValue].
[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_PropertyValue.html
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#interpolation ⇒ Types::InterpolationParameters
An object that specifies the interpolation type and the interval over which to interpolate data.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return at one time. The default is 25.
Valid Range: Minimum value of 1. Maximum value of 250.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The string that specifies the next page of results.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#order_by_time ⇒ String
The time direction to use in the result order.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#property_filters ⇒ Array<Types::PropertyFilter>
A list of objects that filter the property value history request.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#selected_properties ⇒ Array<String>
A list of properties whose value histories the request retrieves.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_date_time ⇒ Time
The date and time of the earliest property value to return.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The ISO8601 DateTime of the earliest property value to return.
For more information about the ISO8601 DateTime format, see the data type [PropertyValue].
[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_PropertyValue.html
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2014 class GetPropertyValueHistoryRequest < Struct.new( :workspace_id, :entity_id, :component_name, :component_type_id, :selected_properties, :property_filters, :start_date_time, :end_date_time, :interpolation, :next_token, :max_results, :order_by_time, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |