Class: Aws::IoTTwinMaker::Types::GetPropertyValueHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
When making an API call, you may pass GetPropertyValueHistoryRequest data as a hash:
{
component_name: "Name",
component_type_id: "ComponentTypeId",
end_date_time: Time.now, # required
entity_id: "EntityId",
interpolation: {
interpolation_type: "LINEAR", # accepts LINEAR
interval_in_seconds: 1,
},
max_results: 1,
next_token: "NextToken",
order_by_time: "ASCENDING", # accepts ASCENDING, DESCENDING
property_filters: [
{
operator: "String",
property_name: "String",
value: {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
},
],
selected_properties: ["String"], # required
start_date_time: Time.now, # required
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component.
-
#component_type_id ⇒ String
The ID of the component type.
-
#end_date_time ⇒ Time
The date and time of the latest property value to return.
-
#entity_id ⇒ String
The ID of the entity.
-
#interpolation ⇒ Types::InterpolationParameters
An object that specifies the interpolation type and the interval over which to interpolate data.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#order_by_time ⇒ String
The time direction to use in the result order.
-
#property_filters ⇒ Array<Types::PropertyFilter>
A list of objects that filter the property value history request.
-
#selected_properties ⇒ Array<String>
A list of properties whose value histories the request retrieves.
-
#start_date_time ⇒ Time
The date and time of the earliest property value to return.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#component_name ⇒ String
The name of the component.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#end_date_time ⇒ Time
The date and time of the latest property value to return.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#interpolation ⇒ Types::InterpolationParameters
An object that specifies the interpolation type and the interval over which to interpolate data.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The string that specifies the next page of results.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#order_by_time ⇒ String
The time direction to use in the result order.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#property_filters ⇒ Array<Types::PropertyFilter>
A list of objects that filter the property value history request.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#selected_properties ⇒ Array<String>
A list of properties whose value histories the request retrieves.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#start_date_time ⇒ Time
The date and time of the earliest property value to return.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1769 class GetPropertyValueHistoryRequest < Struct.new( :component_name, :component_type_id, :end_date_time, :entity_id, :interpolation, :max_results, :next_token, :order_by_time, :property_filters, :selected_properties, :start_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |