Class: Aws::IoTTwinMaker::Types::GetPropertyValueHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueHistoryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#property_values ⇒ Array<Types::PropertyValueHistory>
An object that maps strings to the property definitions in the component type.
Instance Attribute Details
#next_token ⇒ String
The string that specifies the next page of results.
1796 1797 1798 1799 1800 1801 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1796 class GetPropertyValueHistoryResponse < Struct.new( :next_token, :property_values) SENSITIVE = [] include Aws::Structure end |
#property_values ⇒ Array<Types::PropertyValueHistory>
An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.
1796 1797 1798 1799 1800 1801 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1796 class GetPropertyValueHistoryResponse < Struct.new( :next_token, :property_values) SENSITIVE = [] include Aws::Structure end |