Class: Aws::IoTTwinMaker::Types::GetPropertyValueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass GetPropertyValueRequest data as a hash:

{
  component_name: "Name",
  component_type_id: "ComponentTypeId",
  entity_id: "EntityId",
  selected_properties: ["String"], # required
  workspace_id: "Id", # required
  max_results: 1,
  next_token: "NextToken",
  property_group_name: "Name",
  tabular_conditions: {
    order_by: [
      {
        order: "ASCENDING", # accepts ASCENDING, DESCENDING
        property_name: "String", # required
      },
    ],
    property_filters: [
      {
        property_name: "String",
        operator: "String",
        value: {
          boolean_value: false,
          double_value: 1.0,
          integer_value: 1,
          long_value: 1,
          string_value: "String",
          list_value: [
            {
              # recursive DataValue
            },
          ],
          map_value: {
            "String" => {
              # recursive DataValue
            },
          },
          relationship_value: {
            target_entity_id: "EntityId",
            target_component_name: "Name",
          },
          expression: "Expression",
        },
      },
    ],
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_nameString

The name of the component whose property values the operation returns.

Returns:

  • (String)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#component_type_idString

The ID of the component type whose property values the operation returns.

Returns:

  • (String)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity whose property values the operation returns.

Returns:

  • (String)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return at one time. The default is 25.

Valid Range: Minimum value of 1. Maximum value of 250.

Returns:

  • (Integer)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The string that specifies the next page of results.

Returns:

  • (String)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#property_group_nameString

The property group name.

Returns:

  • (String)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#selected_propertiesArray<String>

The properties whose values the operation returns.

Returns:

  • (Array<String>)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#tabular_conditionsTypes::TabularConditions

The tabular conditions.



2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace whose values the operation returns.

Returns:

  • (String)


2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2141

class GetPropertyValueRequest < Struct.new(
  :component_name,
  :component_type_id,
  :entity_id,
  :selected_properties,
  :workspace_id,
  :max_results,
  :next_token,
  :property_group_name,
  :tabular_conditions)
  SENSITIVE = []
  include Aws::Structure
end