Class: Aws::IoTTwinMaker::Types::GetPropertyValueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass GetPropertyValueRequest data as a hash:
{
component_name: "Name",
component_type_id: "ComponentTypeId",
entity_id: "EntityId",
selected_properties: ["String"], # required
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component whose property values the operation returns.
-
#component_type_id ⇒ String
The ID of the component type whose property values the operation returns.
-
#entity_id ⇒ String
The ID of the entity whose property values the operation returns.
-
#selected_properties ⇒ Array<String>
The properties whose values the operation returns.
-
#workspace_id ⇒ String
The ID of the workspace whose values the operation returns.
Instance Attribute Details
#component_name ⇒ String
The name of the component whose property values the operation returns.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1836 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type whose property values the operation returns.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1836 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity whose property values the operation returns.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1836 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#selected_properties ⇒ Array<String>
The properties whose values the operation returns.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1836 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace whose values the operation returns.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1836 class GetPropertyValueRequest < Struct.new( :component_name, :component_type_id, :entity_id, :selected_properties, :workspace_id) SENSITIVE = [] include Aws::Structure end |