Class: Aws::IoTTwinMaker::Types::GetPropertyValueResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#property_values ⇒ Hash<String,Types::PropertyLatestValue>
An object that maps strings to the properties and latest property values in the response.
-
#tabular_property_values ⇒ Array<Array<Hash<String,Types::DataValue>>>
A table of property values.
Instance Attribute Details
#next_token ⇒ String
The string that specifies the next page of results.
1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1449 class GetPropertyValueResponse < Struct.new( :property_values, :next_token, :tabular_property_values) SENSITIVE = [] include Aws::Structure end |
#property_values ⇒ Hash<String,Types::PropertyLatestValue>
An object that maps strings to the properties and latest property values in the response. Each string in the mapping must be unique to this object.
1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1449 class GetPropertyValueResponse < Struct.new( :property_values, :next_token, :tabular_property_values) SENSITIVE = [] include Aws::Structure end |
#tabular_property_values ⇒ Array<Array<Hash<String,Types::DataValue>>>
A table of property values.
1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1449 class GetPropertyValueResponse < Struct.new( :property_values, :next_token, :tabular_property_values) SENSITIVE = [] include Aws::Structure end |