Class: Aws::IoTTwinMaker::Types::GetPropertyValueResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetPropertyValueResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#property_values ⇒ Hash<String,Types::PropertyLatestValue>
An object that maps strings to the properties and latest property values in the response.
Instance Attribute Details
#property_values ⇒ Hash<String,Types::PropertyLatestValue>
An object that maps strings to the properties and latest property values in the response. Each string in the mapping must be unique to this object.
1879 1880 1881 1882 1883 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1879 class GetPropertyValueResponse < Struct.new( :property_values) SENSITIVE = [] include Aws::Structure end |