Class: Aws::IoTTwinMaker::Types::GetSceneResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetSceneResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the scene.
-
#capabilities ⇒ Array<String>
A list of capabilities that the scene uses to render.
-
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
-
#creation_date_time ⇒ Time
The date and time when the scene was created.
-
#description ⇒ String
The description of the scene.
-
#scene_id ⇒ String
The ID of the scene.
-
#update_date_time ⇒ Time
The date and time when the scene was last updated.
-
#workspace_id ⇒ String
The ID of the workspace that contains the scene.
Instance Attribute Details
#arn ⇒ String
The ARN of the scene.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Array<String>
A list of capabilities that the scene uses to render.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the scene was created.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the scene.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#scene_id ⇒ String
The ID of the scene.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the scene was last updated.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the scene.
1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 1914 class GetSceneResponse < Struct.new( :arn, :capabilities, :content_location, :creation_date_time, :description, :scene_id, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |