Class: Aws::IoTTwinMaker::Types::GetWorkspaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the workspace.

Returns:

  • (String)


2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000

class GetWorkspaceResponse < Struct.new(
  :arn,
  :creation_date_time,
  :description,
  :role,
  :s3_location,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeTime

The date and time when the workspace was created.

Returns:

  • (Time)


2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000

class GetWorkspaceResponse < Struct.new(
  :arn,
  :creation_date_time,
  :description,
  :role,
  :s3_location,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the workspace.

Returns:

  • (String)


2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000

class GetWorkspaceResponse < Struct.new(
  :arn,
  :creation_date_time,
  :description,
  :role,
  :s3_location,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The ARN of the execution role associated with the workspace.

Returns:

  • (String)


2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000

class GetWorkspaceResponse < Struct.new(
  :arn,
  :creation_date_time,
  :description,
  :role,
  :s3_location,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationString

The ARN of the S3 bucket where resources associated with the workspace are stored.

Returns:

  • (String)


2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000

class GetWorkspaceResponse < Struct.new(
  :arn,
  :creation_date_time,
  :description,
  :role,
  :s3_location,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The date and time when the workspace was last updated.

Returns:

  • (Time)


2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000

class GetWorkspaceResponse < Struct.new(
  :arn,
  :creation_date_time,
  :description,
  :role,
  :s3_location,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace.

Returns:

  • (String)


2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000

class GetWorkspaceResponse < Struct.new(
  :arn,
  :creation_date_time,
  :description,
  :role,
  :s3_location,
  :update_date_time,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end