Class: Aws::IoTTwinMaker::Types::GetWorkspaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::GetWorkspaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the workspace.
-
#creation_date_time ⇒ Time
The date and time when the workspace was created.
-
#description ⇒ String
The description of the workspace.
-
#role ⇒ String
The ARN of the execution role associated with the workspace.
-
#s3_location ⇒ String
The ARN of the S3 bucket where resources associated with the workspace are stored.
-
#update_date_time ⇒ Time
The date and time when the workspace was last updated.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#arn ⇒ String
The ARN of the workspace.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000 class GetWorkspaceResponse < Struct.new( :arn, :creation_date_time, :description, :role, :s3_location, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the workspace was created.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000 class GetWorkspaceResponse < Struct.new( :arn, :creation_date_time, :description, :role, :s3_location, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the workspace.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000 class GetWorkspaceResponse < Struct.new( :arn, :creation_date_time, :description, :role, :s3_location, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The ARN of the execution role associated with the workspace.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000 class GetWorkspaceResponse < Struct.new( :arn, :creation_date_time, :description, :role, :s3_location, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#s3_location ⇒ String
The ARN of the S3 bucket where resources associated with the workspace are stored.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000 class GetWorkspaceResponse < Struct.new( :arn, :creation_date_time, :description, :role, :s3_location, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the workspace was last updated.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000 class GetWorkspaceResponse < Struct.new( :arn, :creation_date_time, :description, :role, :s3_location, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2000 class GetWorkspaceResponse < Struct.new( :arn, :creation_date_time, :description, :role, :s3_location, :update_date_time, :workspace_id) SENSITIVE = [] include Aws::Structure end |