Class: Aws::IoTTwinMaker::Types::PropertyDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that sets information about a property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property.
-
#data_type ⇒ Types::DataType
An object that contains information about the data type.
-
#default_value ⇒ Types::DataValue
An object that contains the default value.
-
#display_name ⇒ String
A friendly name for the property.
-
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
-
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required.
-
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
-
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
Instance Attribute Details
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property. Use this field to specify information that you read from and write to an external source.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ Types::DataType
An object that contains information about the data type.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ Types::DataValue
An object that contains the default value.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
A friendly name for the property.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2148 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration, :display_name) SENSITIVE = [] include Aws::Structure end |