Class: Aws::IoTTwinMaker::Types::PropertyDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
When making an API call, you may pass PropertyDefinitionRequest data as a hash:
{
data_type: {
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
nested_type: {
# recursive DataType
},
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: {
# recursive DataValueList
},
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
],
unit_of_measure: "String",
relationship: {
target_component_type_id: "ComponentTypeId",
relationship_type: "String",
},
},
is_required_in_entity: false,
is_external_id: false,
is_stored_externally: false,
is_time_series: false,
default_value: {
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: [
{
# recursive DataValue
},
],
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
configuration: {
"Name" => "Value",
},
}
An object that sets information about a property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property.
-
#data_type ⇒ Types::DataType
An object that contains information about the data type.
-
#default_value ⇒ Types::DataValue
An object that contains the default value.
-
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
-
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required.
-
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
-
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
Instance Attribute Details
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property. Use this field to specify information that you read from and write to an external source.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2883 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ Types::DataType
An object that contains information about the data type.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2883 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ Types::DataValue
An object that contains the default value.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2883 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2883 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2883 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2883 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2883 class PropertyDefinitionRequest < Struct.new( :data_type, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_time_series, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |