Class: Aws::IoTTwinMaker::Types::PropertyDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass PropertyDefinitionRequest data as a hash:

{
  configuration: {
    "Name" => "Value",
  },
  data_type: {
    allowed_values: [
      {
        boolean_value: false,
        double_value: 1.0,
        expression: "Expression",
        integer_value: 1,
        list_value: {
          # recursive DataValueList
        },
        long_value: 1,
        map_value: {
          "String" => {
            # recursive DataValue
          },
        },
        relationship_value: {
          target_component_name: "Name",
          target_entity_id: "EntityId",
        },
        string_value: "String",
      },
    ],
    nested_type: {
      # recursive DataType
    },
    relationship: {
      relationship_type: "String",
      target_component_type_id: "ComponentTypeId",
    },
    type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
    unit_of_measure: "String",
  },
  default_value: {
    boolean_value: false,
    double_value: 1.0,
    expression: "Expression",
    integer_value: 1,
    list_value: [
      {
        # recursive DataValue
      },
    ],
    long_value: 1,
    map_value: {
      "String" => {
        # recursive DataValue
      },
    },
    relationship_value: {
      target_component_name: "Name",
      target_entity_id: "EntityId",
    },
    string_value: "String",
  },
  is_external_id: false,
  is_required_in_entity: false,
  is_stored_externally: false,
  is_time_series: false,
}

An object that sets information about a property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationHash<String,String>

A mapping that specifies configuration information about the property. Use this field to specify information that you read from and write to an external source.

Returns:

  • (Hash<String,String>)


2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2516

class PropertyDefinitionRequest < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeTypes::DataType

An object that contains information about the data type.

Returns:



2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2516

class PropertyDefinitionRequest < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#default_valueTypes::DataValue

An object that contains the default value.

Returns:



2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2516

class PropertyDefinitionRequest < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_external_idBoolean

A Boolean value that specifies whether the property ID comes from an external data store.

Returns:

  • (Boolean)


2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2516

class PropertyDefinitionRequest < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_required_in_entityBoolean

A Boolean value that specifies whether the property is required.

Returns:

  • (Boolean)


2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2516

class PropertyDefinitionRequest < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_stored_externallyBoolean

A Boolean value that specifies whether the property is stored externally.

Returns:

  • (Boolean)


2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2516

class PropertyDefinitionRequest < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_time_seriesBoolean

A Boolean value that specifies whether the property consists of time series data.

Returns:

  • (Boolean)


2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2516

class PropertyDefinitionRequest < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end