Class: Aws::IoTTwinMaker::Types::PropertyDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
When making an API call, you may pass PropertyDefinitionRequest data as a hash:
{
configuration: {
"Name" => "Value",
},
data_type: {
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: {
# recursive DataValueList
},
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
],
nested_type: {
# recursive DataType
},
relationship: {
relationship_type: "String",
target_component_type_id: "ComponentTypeId",
},
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
unit_of_measure: "String",
},
default_value: {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
is_external_id: false,
is_required_in_entity: false,
is_stored_externally: false,
is_time_series: false,
}
An object that sets information about a property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property.
-
#data_type ⇒ Types::DataType
An object that contains information about the data type.
-
#default_value ⇒ Types::DataValue
An object that contains the default value.
-
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
-
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required.
-
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
-
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
Instance Attribute Details
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property. Use this field to specify information that you read from and write to an external source.
2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2473 class PropertyDefinitionRequest < Struct.new( :configuration, :data_type, :default_value, :is_external_id, :is_required_in_entity, :is_stored_externally, :is_time_series) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ Types::DataType
An object that contains information about the data type.
2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2473 class PropertyDefinitionRequest < Struct.new( :configuration, :data_type, :default_value, :is_external_id, :is_required_in_entity, :is_stored_externally, :is_time_series) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ Types::DataValue
An object that contains the default value.
2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2473 class PropertyDefinitionRequest < Struct.new( :configuration, :data_type, :default_value, :is_external_id, :is_required_in_entity, :is_stored_externally, :is_time_series) SENSITIVE = [] include Aws::Structure end |
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2473 class PropertyDefinitionRequest < Struct.new( :configuration, :data_type, :default_value, :is_external_id, :is_required_in_entity, :is_stored_externally, :is_time_series) SENSITIVE = [] include Aws::Structure end |
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required.
2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2473 class PropertyDefinitionRequest < Struct.new( :configuration, :data_type, :default_value, :is_external_id, :is_required_in_entity, :is_stored_externally, :is_time_series) SENSITIVE = [] include Aws::Structure end |
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2473 class PropertyDefinitionRequest < Struct.new( :configuration, :data_type, :default_value, :is_external_id, :is_required_in_entity, :is_stored_externally, :is_time_series) SENSITIVE = [] include Aws::Structure end |
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2473 class PropertyDefinitionRequest < Struct.new( :configuration, :data_type, :default_value, :is_external_id, :is_required_in_entity, :is_stored_externally, :is_time_series) SENSITIVE = [] include Aws::Structure end |