Class: Aws::IoTTwinMaker::Types::PropertyDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that contains response data from a property definition request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property.
-
#data_type ⇒ Types::DataType
An object that contains information about the data type.
-
#default_value ⇒ Types::DataValue
An object that contains the default value.
-
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
-
#is_final ⇒ Boolean
A Boolean value that specifies whether the property definition can be updated.
-
#is_imported ⇒ Boolean
A Boolean value that specifies whether the property definition is imported from an external data store.
-
#is_inherited ⇒ Boolean
A Boolean value that specifies whether the property definition is inherited from a parent entity.
-
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required in an entity.
-
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
-
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
Instance Attribute Details
#configuration ⇒ Hash<String,String>
A mapping that specifies configuration information about the property.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ Types::DataType
An object that contains information about the data type.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ Types::DataValue
An object that contains the default value.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_external_id ⇒ Boolean
A Boolean value that specifies whether the property ID comes from an external data store.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_final ⇒ Boolean
A Boolean value that specifies whether the property definition can be updated.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_imported ⇒ Boolean
A Boolean value that specifies whether the property definition is imported from an external data store.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_inherited ⇒ Boolean
A Boolean value that specifies whether the property definition is inherited from a parent entity.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_required_in_entity ⇒ Boolean
A Boolean value that specifies whether the property is required in an entity.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_stored_externally ⇒ Boolean
A Boolean value that specifies whether the property is stored externally.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |
#is_time_series ⇒ Boolean
A Boolean value that specifies whether the property consists of time series data.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2946 class PropertyDefinitionResponse < Struct.new( :data_type, :is_time_series, :is_required_in_entity, :is_external_id, :is_stored_externally, :is_imported, :is_final, :is_inherited, :default_value, :configuration) SENSITIVE = [] include Aws::Structure end |