Class: Aws::IoTTwinMaker::Types::PropertyDefinitionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

An object that contains response data from a property definition request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationHash<String,String>

A mapping that specifies configuration information about the property.

Returns:

  • (Hash<String,String>)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeTypes::DataType

An object that contains information about the data type.

Returns:



2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#default_valueTypes::DataValue

An object that contains the default value.

Returns:



2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_external_idBoolean

A Boolean value that specifies whether the property ID comes from an external data store.

Returns:

  • (Boolean)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_finalBoolean

A Boolean value that specifies whether the property definition can be updated.

Returns:

  • (Boolean)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_importedBoolean

A Boolean value that specifies whether the property definition is imported from an external data store.

Returns:

  • (Boolean)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_inheritedBoolean

A Boolean value that specifies whether the property definition is inherited from a parent entity.

Returns:

  • (Boolean)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_required_in_entityBoolean

A Boolean value that specifies whether the property is required in an entity.

Returns:

  • (Boolean)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_stored_externallyBoolean

A Boolean value that specifies whether the property is stored externally.

Returns:

  • (Boolean)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end

#is_time_seriesBoolean

A Boolean value that specifies whether the property consists of time series data.

Returns:

  • (Boolean)


2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2536

class PropertyDefinitionResponse < Struct.new(
  :configuration,
  :data_type,
  :default_value,
  :is_external_id,
  :is_final,
  :is_imported,
  :is_inherited,
  :is_required_in_entity,
  :is_stored_externally,
  :is_time_series)
  SENSITIVE = []
  include Aws::Structure
end