Class: Aws::IoTTwinMaker::Types::PropertyValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass PropertyValue data as a hash:

{
  timestamp: Time.now,
  value: { # required
    boolean_value: false,
    double_value: 1.0,
    integer_value: 1,
    long_value: 1,
    string_value: "String",
    list_value: [
      {
        # recursive DataValue
      },
    ],
    map_value: {
      "String" => {
        # recursive DataValue
      },
    },
    relationship_value: {
      target_entity_id: "EntityId",
      target_component_name: "Name",
    },
    expression: "Expression",
  },
  time: "Time",
}

An object that contains information about a value for a time series property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#timeString

ISO8601 DateTime of a value for a time series property.

The time for when the property value was recorded in ISO 8601 format: *YYYY-MM-DDThh:mm:ss[Z/±HH:mm]*.

  • *[YYYY]*: year

  • *[MM]*: month

  • *[DD]*: day

  • *[hh]*: hour

  • *[mm]*: minute

  • *[ss]*: seconds

  • *[.SSSSSSSSS]*: additional precision, where precedence is maintained. For example: [.573123] is equal to 573123000 nanoseconds.

  • Z: default timezone UTC

  • *± HH:mm*: time zone offset in Hours and Minutes.

*Required sub-fields*: YYYY-MM-DDThh:mm:ss and [Z/±HH:mm]

Returns:

  • (String)


3278
3279
3280
3281
3282
3283
3284
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3278

class PropertyValue < Struct.new(
  :timestamp,
  :value,
  :time)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The timestamp of a value for a time series property.

Returns:

  • (Time)


3278
3279
3280
3281
3282
3283
3284
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3278

class PropertyValue < Struct.new(
  :timestamp,
  :value,
  :time)
  SENSITIVE = []
  include Aws::Structure
end

#valueTypes::DataValue

An object that specifies a value for a time series property.

Returns:



3278
3279
3280
3281
3282
3283
3284
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3278

class PropertyValue < Struct.new(
  :timestamp,
  :value,
  :time)
  SENSITIVE = []
  include Aws::Structure
end