Class: Aws::IoTTwinMaker::Types::PropertyValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass PropertyValue data as a hash:

{
  time: "Time",
  timestamp: Time.now,
  value: { # required
    boolean_value: false,
    double_value: 1.0,
    expression: "Expression",
    integer_value: 1,
    list_value: [
      {
        # recursive DataValue
      },
    ],
    long_value: 1,
    map_value: {
      "String" => {
        # recursive DataValue
      },
    },
    relationship_value: {
      target_component_name: "Name",
      target_entity_id: "EntityId",
    },
    string_value: "String",
  },
}

An object that contains information about a value for a time series property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#timeString

Timestamp represented in ISO 8601 format

Returns:

  • (String)


2818
2819
2820
2821
2822
2823
2824
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2818

class PropertyValue < Struct.new(
  :time,
  :timestamp,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The timestamp of a value for a time series property.

Returns:

  • (Time)


2818
2819
2820
2821
2822
2823
2824
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2818

class PropertyValue < Struct.new(
  :time,
  :timestamp,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueTypes::DataValue

An object that specifies a value for a time series property.

Returns:



2818
2819
2820
2821
2822
2823
2824
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2818

class PropertyValue < Struct.new(
  :time,
  :timestamp,
  :value)
  SENSITIVE = []
  include Aws::Structure
end