Class: Aws::IoTTwinMaker::Types::PropertyValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass PropertyValue data as a hash:
{
timestamp: Time.now, # required
value: { # required
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
}
An object that contains information about a value for a time series property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#timestamp ⇒ Time
The timestamp of a value for a time series property.
-
#value ⇒ Types::DataValue
An object that specifies a value for a time series property.
Instance Attribute Details
#timestamp ⇒ Time
The timestamp of a value for a time series property.
2792 2793 2794 2795 2796 2797 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2792 class PropertyValue < Struct.new( :timestamp, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Types::DataValue
An object that specifies a value for a time series property.
2792 2793 2794 2795 2796 2797 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2792 class PropertyValue < Struct.new( :timestamp, :value) SENSITIVE = [] include Aws::Structure end |