Class: Aws::IoTTwinMaker::Types::PropertyValueEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::PropertyValueEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass PropertyValueEntry data as a hash:
{
entity_property_reference: { # required
component_name: "Name",
entity_id: "EntityId",
external_id_property: {
"String" => "String",
},
property_name: "Name", # required
},
property_values: [
{
time: "Time",
timestamp: Time.now,
value: { # required
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
},
],
}
An object that specifies information about time series property values. This object is used and consumed by the
- BatchPutPropertyValues][1
-
action.
[1]: docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_BatchPutPropertyValues.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity_property_reference ⇒ Types::EntityPropertyReference
An object that contains information about the entity that has the property.
-
#property_values ⇒ Array<Types::PropertyValue>
A list of objects that specify time series property values.
Instance Attribute Details
#entity_property_reference ⇒ Types::EntityPropertyReference
An object that contains information about the entity that has the property.
2932 2933 2934 2935 2936 2937 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2932 class PropertyValueEntry < Struct.new( :entity_property_reference, :property_values) SENSITIVE = [] include Aws::Structure end |
#property_values ⇒ Array<Types::PropertyValue>
A list of objects that specify time series property values.
2932 2933 2934 2935 2936 2937 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2932 class PropertyValueEntry < Struct.new( :entity_property_reference, :property_values) SENSITIVE = [] include Aws::Structure end |