Class: Aws::IoTTwinMaker::Types::Relationship
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::Relationship
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass Relationship data as a hash:
{
relationship_type: "String",
target_component_type_id: "ComponentTypeId",
}
An object that specifies a relationship with another component type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#relationship_type ⇒ String
The type of the relationship.
-
#target_component_type_id ⇒ String
The ID of the target component type associated with this relationship.
Instance Attribute Details
#relationship_type ⇒ String
The type of the relationship.
2896 2897 2898 2899 2900 2901 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2896 class Relationship < Struct.new( :relationship_type, :target_component_type_id) SENSITIVE = [] include Aws::Structure end |
#target_component_type_id ⇒ String
The ID of the target component type associated with this relationship.
2896 2897 2898 2899 2900 2901 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2896 class Relationship < Struct.new( :relationship_type, :target_component_type_id) SENSITIVE = [] include Aws::Structure end |