Class: Aws::IoTTwinMaker::Types::RelationshipValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

Note:

When making an API call, you may pass RelationshipValue data as a hash:

{
  target_entity_id: "EntityId",
  target_component_name: "Name",
}

A value that associates a component and an entity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#target_component_nameString

The name of the target component associated with the relationship value.

Returns:

  • (String)


3426
3427
3428
3429
3430
3431
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3426

class RelationshipValue < Struct.new(
  :target_entity_id,
  :target_component_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_entity_idString

The ID of the target entity associated with this relationship value.

Returns:

  • (String)


3426
3427
3428
3429
3430
3431
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3426

class RelationshipValue < Struct.new(
  :target_entity_id,
  :target_component_name)
  SENSITIVE = []
  include Aws::Structure
end