Class: Aws::IoTTwinMaker::Types::RelationshipValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::RelationshipValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass RelationshipValue data as a hash:
{
target_component_name: "Name",
target_entity_id: "EntityId",
}
A value that associates a component and an entity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_component_name ⇒ String
The name of the target component associated with the relationship value.
-
#target_entity_id ⇒ String
The ID of the target entity associated with this relationship value.
Instance Attribute Details
#target_component_name ⇒ String
The name of the target component associated with the relationship value.
2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2922 class RelationshipValue < Struct.new( :target_component_name, :target_entity_id) SENSITIVE = [] include Aws::Structure end |
#target_entity_id ⇒ String
The ID of the target entity associated with this relationship value.
2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2922 class RelationshipValue < Struct.new( :target_component_name, :target_entity_id) SENSITIVE = [] include Aws::Structure end |