Class: Aws::IoTTwinMaker::Types::SceneSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::SceneSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
An object that contains information about a scene.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the scene.
-
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
-
#creation_date_time ⇒ Time
The date and time when the scene was created.
-
#description ⇒ String
The scene description.
-
#scene_id ⇒ String
The ID of the scene.
-
#update_date_time ⇒ Time
The date and time when the scene was last updated.
Instance Attribute Details
#arn ⇒ String
The ARN of the scene.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2967 class SceneSummary < Struct.new( :arn, :content_location, :creation_date_time, :description, :scene_id, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#content_location ⇒ String
The relative path that specifies the location of the content definition file.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2967 class SceneSummary < Struct.new( :arn, :content_location, :creation_date_time, :description, :scene_id, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The date and time when the scene was created.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2967 class SceneSummary < Struct.new( :arn, :content_location, :creation_date_time, :description, :scene_id, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The scene description.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2967 class SceneSummary < Struct.new( :arn, :content_location, :creation_date_time, :description, :scene_id, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#scene_id ⇒ String
The ID of the scene.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2967 class SceneSummary < Struct.new( :arn, :content_location, :creation_date_time, :description, :scene_id, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the scene was last updated.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2967 class SceneSummary < Struct.new( :arn, :content_location, :creation_date_time, :description, :scene_id, :update_date_time) SENSITIVE = [] include Aws::Structure end |