Class: Aws::IoTTwinMaker::Types::Status

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Overview

An object that represents the status of an entity, component, component type, or workspace.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::ErrorDetails

The error message.

Returns:



3081
3082
3083
3084
3085
3086
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3081

class Status < Struct.new(
  :error,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the entity, component, component type, or workspace.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3081

class Status < Struct.new(
  :error,
  :state)
  SENSITIVE = []
  include Aws::Structure
end