Class: Aws::IoTTwinMaker::Types::SyncJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::SyncJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
The SyncJob summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The SyncJob summary ARN.
-
#creation_date_time ⇒ Time
The creation date and time.
-
#status ⇒ Types::SyncJobStatus
The SyncJob summaries status.
-
#sync_source ⇒ String
The sync source.
-
#update_date_time ⇒ Time
The update date and time.
-
#workspace_id ⇒ String
The ID of the workspace that contains the sync job.
Instance Attribute Details
#arn ⇒ String
The SyncJob summary ARN.
2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2619 class SyncJobSummary < Struct.new( :arn, :workspace_id, :sync_source, :status, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ Time
The creation date and time.
2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2619 class SyncJobSummary < Struct.new( :arn, :workspace_id, :sync_source, :status, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::SyncJobStatus
The SyncJob summaries status.
2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2619 class SyncJobSummary < Struct.new( :arn, :workspace_id, :sync_source, :status, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#sync_source ⇒ String
The sync source.
2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2619 class SyncJobSummary < Struct.new( :arn, :workspace_id, :sync_source, :status, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The update date and time.
2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2619 class SyncJobSummary < Struct.new( :arn, :workspace_id, :sync_source, :status, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the sync job.
2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2619 class SyncJobSummary < Struct.new( :arn, :workspace_id, :sync_source, :status, :creation_date_time, :update_date_time) SENSITIVE = [] include Aws::Structure end |