Class: Aws::IoTTwinMaker::Types::UpdateComponentTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateComponentTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
When making an API call, you may pass UpdateComponentTypeRequest data as a hash:
{
component_type_id: "ComponentTypeId", # required
description: "Description",
extends_from: ["ComponentTypeId"],
functions: {
"Name" => {
implemented_by: {
is_native: false,
lambda: {
arn: "LambdaArn", # required
},
},
required_properties: ["Name"],
scope: "ENTITY", # accepts ENTITY, WORKSPACE
},
},
is_singleton: false,
property_definitions: {
"Name" => {
configuration: {
"Name" => "Value",
},
data_type: {
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: {
# recursive DataValueList
},
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
],
nested_type: {
# recursive DataType
},
relationship: {
relationship_type: "String",
target_component_type_id: "ComponentTypeId",
},
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
unit_of_measure: "String",
},
default_value: {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
is_external_id: false,
is_required_in_entity: false,
is_stored_externally: false,
is_time_series: false,
},
},
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_type_id ⇒ String
The ID of the component type.
-
#description ⇒ String
The description of the component type.
-
#extends_from ⇒ Array<String>
Specifies the component type that this component type extends.
-
#functions ⇒ Hash<String,Types::FunctionRequest>
An object that maps strings to the functions in the component type.
-
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
-
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionRequest>
An object that maps strings to the property definitions in the component type.
-
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
Instance Attribute Details
#component_type_id ⇒ String
The ID of the component type.
3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3285 class UpdateComponentTypeRequest < Struct.new( :component_type_id, :description, :extends_from, :functions, :is_singleton, :property_definitions, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component type.
3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3285 class UpdateComponentTypeRequest < Struct.new( :component_type_id, :description, :extends_from, :functions, :is_singleton, :property_definitions, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#extends_from ⇒ Array<String>
Specifies the component type that this component type extends.
3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3285 class UpdateComponentTypeRequest < Struct.new( :component_type_id, :description, :extends_from, :functions, :is_singleton, :property_definitions, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#functions ⇒ Hash<String,Types::FunctionRequest>
An object that maps strings to the functions in the component type. Each string in the mapping must be unique to this object.
3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3285 class UpdateComponentTypeRequest < Struct.new( :component_type_id, :description, :extends_from, :functions, :is_singleton, :property_definitions, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#is_singleton ⇒ Boolean
A Boolean value that specifies whether an entity can have more than one component of this type.
3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3285 class UpdateComponentTypeRequest < Struct.new( :component_type_id, :description, :extends_from, :functions, :is_singleton, :property_definitions, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#property_definitions ⇒ Hash<String,Types::PropertyDefinitionRequest>
An object that maps strings to the property definitions in the component type. Each string in the mapping must be unique to this object.
3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3285 class UpdateComponentTypeRequest < Struct.new( :component_type_id, :description, :extends_from, :functions, :is_singleton, :property_definitions, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3285 class UpdateComponentTypeRequest < Struct.new( :component_type_id, :description, :extends_from, :functions, :is_singleton, :property_definitions, :workspace_id) SENSITIVE = [] include Aws::Structure end |