Class: Aws::IoTTwinMaker::Types::UpdateComponentTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateComponentTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the component type.
-
#component_type_id ⇒ String
The ID of the component type.
-
#state ⇒ String
The current state of the component type.
-
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
Instance Attribute Details
#arn ⇒ String
The ARN of the component type.
3261 3262 3263 3264 3265 3266 3267 3268 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3261 class UpdateComponentTypeResponse < Struct.new( :arn, :component_type_id, :state, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#component_type_id ⇒ String
The ID of the component type.
3261 3262 3263 3264 3265 3266 3267 3268 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3261 class UpdateComponentTypeResponse < Struct.new( :arn, :component_type_id, :state, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the component type.
3261 3262 3263 3264 3265 3266 3267 3268 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3261 class UpdateComponentTypeResponse < Struct.new( :arn, :component_type_id, :state, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the component type.
3261 3262 3263 3264 3265 3266 3267 3268 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3261 class UpdateComponentTypeResponse < Struct.new( :arn, :component_type_id, :state, :workspace_id) SENSITIVE = [] include Aws::Structure end |