Class: Aws::IoTTwinMaker::Types::UpdateEntityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateEntityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_updates ⇒ Hash<String,Types::ComponentUpdateRequest>
An object that maps strings to the component updates in the request.
-
#description ⇒ String
The description of the entity.
-
#entity_id ⇒ String
The ID of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#parent_entity_update ⇒ Types::ParentEntityUpdateRequest
An object that describes the update request for a parent entity.
-
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
Instance Attribute Details
#component_updates ⇒ Hash<String,Types::ComponentUpdateRequest>
An object that maps strings to the component updates in the request. Each string in the mapping must be unique to this object.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2924 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the entity.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2924 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2924 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2924 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#parent_entity_update ⇒ Types::ParentEntityUpdateRequest
An object that describes the update request for a parent entity.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2924 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2924 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |