Class: Aws::IoTTwinMaker::Types::UpdateEntityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iottwinmaker/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_updatesHash<String,Types::ComponentUpdateRequest>

An object that maps strings to the component updates in the request. Each string in the mapping must be unique to this object.

Returns:



2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2899

class UpdateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :component_updates,
  :parent_entity_update)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entity.

Returns:

  • (String)


2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2899

class UpdateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :component_updates,
  :parent_entity_update)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the entity.

Returns:

  • (String)


2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2899

class UpdateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :component_updates,
  :parent_entity_update)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

The name of the entity.

Returns:

  • (String)


2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2899

class UpdateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :component_updates,
  :parent_entity_update)
  SENSITIVE = []
  include Aws::Structure
end

#parent_entity_updateTypes::ParentEntityUpdateRequest

An object that describes the update request for a parent entity.



2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2899

class UpdateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :component_updates,
  :parent_entity_update)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace that contains the entity.

Returns:

  • (String)


2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 2899

class UpdateEntityRequest < Struct.new(
  :workspace_id,
  :entity_id,
  :entity_name,
  :description,
  :component_updates,
  :parent_entity_update)
  SENSITIVE = []
  include Aws::Structure
end