Class: Aws::IoTTwinMaker::Types::UpdateEntityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateEntityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass UpdateEntityRequest data as a hash:
{
workspace_id: "Id", # required
entity_id: "EntityId", # required
entity_name: "EntityName",
description: "Description",
component_updates: {
"Name" => {
update_type: "CREATE", # accepts CREATE, UPDATE, DELETE
description: "Description",
component_type_id: "ComponentTypeId",
property_updates: {
"Name" => {
definition: {
data_type: {
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
nested_type: {
# recursive DataType
},
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: {
# recursive DataValueList
},
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
],
unit_of_measure: "String",
relationship: {
target_component_type_id: "ComponentTypeId",
relationship_type: "String",
},
},
is_required_in_entity: false,
is_external_id: false,
is_stored_externally: false,
is_time_series: false,
default_value: {
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: [
{
# recursive DataValue
},
],
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
configuration: {
"Name" => "Value",
},
},
value: {
boolean_value: false,
double_value: 1.0,
integer_value: 1,
long_value: 1,
string_value: "String",
list_value: [
{
# recursive DataValue
},
],
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_entity_id: "EntityId",
target_component_name: "Name",
},
expression: "Expression",
},
update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
},
},
property_group_updates: {
"Name" => {
group_type: "TABULAR", # accepts TABULAR
property_names: ["Name"],
update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
},
},
},
},
parent_entity_update: {
update_type: "UPDATE", # required, accepts UPDATE, DELETE
parent_entity_id: "ParentEntityId",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_updates ⇒ Hash<String,Types::ComponentUpdateRequest>
An object that maps strings to the component updates in the request.
-
#description ⇒ String
The description of the entity.
-
#entity_id ⇒ String
The ID of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#parent_entity_update ⇒ Types::ParentEntityUpdateRequest
An object that describes the update request for a parent entity.
-
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
Instance Attribute Details
#component_updates ⇒ Hash<String,Types::ComponentUpdateRequest>
An object that maps strings to the component updates in the request. Each string in the mapping must be unique to this object.
3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3974 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the entity.
3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3974 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3974 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3974 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#parent_entity_update ⇒ Types::ParentEntityUpdateRequest
An object that describes the update request for a parent entity.
3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3974 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3974 class UpdateEntityRequest < Struct.new( :workspace_id, :entity_id, :entity_name, :description, :component_updates, :parent_entity_update) SENSITIVE = [] include Aws::Structure end |