Class: Aws::IoTTwinMaker::Types::UpdateEntityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateEntityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass UpdateEntityRequest data as a hash:
{
component_updates: {
"Name" => {
component_type_id: "ComponentTypeId",
description: "Description",
property_updates: {
"Name" => {
definition: {
configuration: {
"Name" => "Value",
},
data_type: {
allowed_values: [
{
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: {
# recursive DataValueList
},
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
],
nested_type: {
# recursive DataType
},
relationship: {
relationship_type: "String",
target_component_type_id: "ComponentTypeId",
},
type: "RELATIONSHIP", # required, accepts RELATIONSHIP, STRING, LONG, BOOLEAN, INTEGER, DOUBLE, LIST, MAP
unit_of_measure: "String",
},
default_value: {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
is_external_id: false,
is_required_in_entity: false,
is_stored_externally: false,
is_time_series: false,
},
update_type: "UPDATE", # accepts UPDATE, DELETE, CREATE
value: {
boolean_value: false,
double_value: 1.0,
expression: "Expression",
integer_value: 1,
list_value: [
{
# recursive DataValue
},
],
long_value: 1,
map_value: {
"String" => {
# recursive DataValue
},
},
relationship_value: {
target_component_name: "Name",
target_entity_id: "EntityId",
},
string_value: "String",
},
},
},
update_type: "CREATE", # accepts CREATE, UPDATE, DELETE
},
},
description: "Description",
entity_id: "EntityId", # required
entity_name: "EntityName",
parent_entity_update: {
parent_entity_id: "ParentEntityId",
update_type: "UPDATE", # required, accepts UPDATE, DELETE
},
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_updates ⇒ Hash<String,Types::ComponentUpdateRequest>
An object that maps strings to the component updates in the request.
-
#description ⇒ String
The description of the entity.
-
#entity_id ⇒ String
The ID of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#parent_entity_update ⇒ Types::ParentEntityUpdateRequest
An object that describes the update request for a parent entity.
-
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
Instance Attribute Details
#component_updates ⇒ Hash<String,Types::ComponentUpdateRequest>
An object that maps strings to the component updates in the request. Each string in the mapping must be unique to this object.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3407 class UpdateEntityRequest < Struct.new( :component_updates, :description, :entity_id, :entity_name, :parent_entity_update, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the entity.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3407 class UpdateEntityRequest < Struct.new( :component_updates, :description, :entity_id, :entity_name, :parent_entity_update, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The ID of the entity.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3407 class UpdateEntityRequest < Struct.new( :component_updates, :description, :entity_id, :entity_name, :parent_entity_update, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3407 class UpdateEntityRequest < Struct.new( :component_updates, :description, :entity_id, :entity_name, :parent_entity_update, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#parent_entity_update ⇒ Types::ParentEntityUpdateRequest
An object that describes the update request for a parent entity.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3407 class UpdateEntityRequest < Struct.new( :component_updates, :description, :entity_id, :entity_name, :parent_entity_update, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that contains the entity.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3407 class UpdateEntityRequest < Struct.new( :component_updates, :description, :entity_id, :entity_name, :parent_entity_update, :workspace_id) SENSITIVE = [] include Aws::Structure end |