Class: Aws::IoTTwinMaker::Types::UpdateEntityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateEntityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The current state of the entity update.
-
#update_date_time ⇒ Time
The date and time when the entity was last updated.
Instance Attribute Details
#state ⇒ String
The current state of the entity update.
3398 3399 3400 3401 3402 3403 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3398 class UpdateEntityResponse < Struct.new( :state, :update_date_time) SENSITIVE = [] include Aws::Structure end |
#update_date_time ⇒ Time
The date and time when the entity was last updated.
3398 3399 3400 3401 3402 3403 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3398 class UpdateEntityResponse < Struct.new( :state, :update_date_time) SENSITIVE = [] include Aws::Structure end |