Class: Aws::IoTTwinMaker::Types::UpdateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTTwinMaker::Types::UpdateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iottwinmaker/types.rb
Overview
Note:
When making an API call, you may pass UpdateWorkspaceRequest data as a hash:
{
description: "Description",
role: "RoleArn",
workspace_id: "Id", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the workspace.
-
#role ⇒ String
The ARN of the execution role associated with the workspace.
-
#workspace_id ⇒ String
The ID of the workspace.
Instance Attribute Details
#description ⇒ String
The description of the workspace.
3506 3507 3508 3509 3510 3511 3512 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3506 class UpdateWorkspaceRequest < Struct.new( :description, :role, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The ARN of the execution role associated with the workspace.
3506 3507 3508 3509 3510 3511 3512 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3506 class UpdateWorkspaceRequest < Struct.new( :description, :role, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace.
3506 3507 3508 3509 3510 3511 3512 |
# File 'lib/aws-sdk-iottwinmaker/types.rb', line 3506 class UpdateWorkspaceRequest < Struct.new( :description, :role, :workspace_id) SENSITIVE = [] include Aws::Structure end |